
#line 2 "lex.swf4.c"

#define  YY_INT_ALIGNED short int

/* A lexical scanner generated by flex */

#define yy_create_buffer swf4_create_buffer
#define yy_delete_buffer swf4_delete_buffer
#define yy_scan_buffer swf4_scan_buffer
#define yy_scan_string swf4_scan_string
#define yy_scan_bytes swf4_scan_bytes
#define yy_init_buffer swf4_init_buffer
#define yy_flush_buffer swf4_flush_buffer
#define yy_load_buffer_state swf4_load_buffer_state
#define yy_switch_to_buffer swf4_switch_to_buffer
#define yypush_buffer_state swf4push_buffer_state
#define yypop_buffer_state swf4pop_buffer_state
#define yyensure_buffer_stack swf4ensure_buffer_stack
#define yy_flex_debug swf4_flex_debug
#define yyin swf4in
#define yyleng swf4leng
#define yylex swf4lex
#define yylineno swf4lineno
#define yyout swf4out
#define yyrestart swf4restart
#define yytext swf4text
#define yywrap swf4wrap
#define yyalloc swf4alloc
#define yyrealloc swf4realloc
#define yyfree swf4free

#define FLEX_SCANNER
#define YY_FLEX_MAJOR_VERSION 2
#define YY_FLEX_MINOR_VERSION 6
#define YY_FLEX_SUBMINOR_VERSION 4
#if YY_FLEX_SUBMINOR_VERSION > 0
#define FLEX_BETA
#endif

#ifdef yy_create_buffer
#define swf4_create_buffer_ALREADY_DEFINED
#else
#define yy_create_buffer swf4_create_buffer
#endif

#ifdef yy_delete_buffer
#define swf4_delete_buffer_ALREADY_DEFINED
#else
#define yy_delete_buffer swf4_delete_buffer
#endif

#ifdef yy_scan_buffer
#define swf4_scan_buffer_ALREADY_DEFINED
#else
#define yy_scan_buffer swf4_scan_buffer
#endif

#ifdef yy_scan_string
#define swf4_scan_string_ALREADY_DEFINED
#else
#define yy_scan_string swf4_scan_string
#endif

#ifdef yy_scan_bytes
#define swf4_scan_bytes_ALREADY_DEFINED
#else
#define yy_scan_bytes swf4_scan_bytes
#endif

#ifdef yy_init_buffer
#define swf4_init_buffer_ALREADY_DEFINED
#else
#define yy_init_buffer swf4_init_buffer
#endif

#ifdef yy_flush_buffer
#define swf4_flush_buffer_ALREADY_DEFINED
#else
#define yy_flush_buffer swf4_flush_buffer
#endif

#ifdef yy_load_buffer_state
#define swf4_load_buffer_state_ALREADY_DEFINED
#else
#define yy_load_buffer_state swf4_load_buffer_state
#endif

#ifdef yy_switch_to_buffer
#define swf4_switch_to_buffer_ALREADY_DEFINED
#else
#define yy_switch_to_buffer swf4_switch_to_buffer
#endif

#ifdef yypush_buffer_state
#define swf4push_buffer_state_ALREADY_DEFINED
#else
#define yypush_buffer_state swf4push_buffer_state
#endif

#ifdef yypop_buffer_state
#define swf4pop_buffer_state_ALREADY_DEFINED
#else
#define yypop_buffer_state swf4pop_buffer_state
#endif

#ifdef yyensure_buffer_stack
#define swf4ensure_buffer_stack_ALREADY_DEFINED
#else
#define yyensure_buffer_stack swf4ensure_buffer_stack
#endif

#ifdef yylex
#define swf4lex_ALREADY_DEFINED
#else
#define yylex swf4lex
#endif

#ifdef yyrestart
#define swf4restart_ALREADY_DEFINED
#else
#define yyrestart swf4restart
#endif

#ifdef yylex_init
#define swf4lex_init_ALREADY_DEFINED
#else
#define yylex_init swf4lex_init
#endif

#ifdef yylex_init_extra
#define swf4lex_init_extra_ALREADY_DEFINED
#else
#define yylex_init_extra swf4lex_init_extra
#endif

#ifdef yylex_destroy
#define swf4lex_destroy_ALREADY_DEFINED
#else
#define yylex_destroy swf4lex_destroy
#endif

#ifdef yyget_debug
#define swf4get_debug_ALREADY_DEFINED
#else
#define yyget_debug swf4get_debug
#endif

#ifdef yyset_debug
#define swf4set_debug_ALREADY_DEFINED
#else
#define yyset_debug swf4set_debug
#endif

#ifdef yyget_extra
#define swf4get_extra_ALREADY_DEFINED
#else
#define yyget_extra swf4get_extra
#endif

#ifdef yyset_extra
#define swf4set_extra_ALREADY_DEFINED
#else
#define yyset_extra swf4set_extra
#endif

#ifdef yyget_in
#define swf4get_in_ALREADY_DEFINED
#else
#define yyget_in swf4get_in
#endif

#ifdef yyset_in
#define swf4set_in_ALREADY_DEFINED
#else
#define yyset_in swf4set_in
#endif

#ifdef yyget_out
#define swf4get_out_ALREADY_DEFINED
#else
#define yyget_out swf4get_out
#endif

#ifdef yyset_out
#define swf4set_out_ALREADY_DEFINED
#else
#define yyset_out swf4set_out
#endif

#ifdef yyget_leng
#define swf4get_leng_ALREADY_DEFINED
#else
#define yyget_leng swf4get_leng
#endif

#ifdef yyget_text
#define swf4get_text_ALREADY_DEFINED
#else
#define yyget_text swf4get_text
#endif

#ifdef yyget_lineno
#define swf4get_lineno_ALREADY_DEFINED
#else
#define yyget_lineno swf4get_lineno
#endif

#ifdef yyset_lineno
#define swf4set_lineno_ALREADY_DEFINED
#else
#define yyset_lineno swf4set_lineno
#endif

#ifdef yywrap
#define swf4wrap_ALREADY_DEFINED
#else
#define yywrap swf4wrap
#endif

#ifdef yyalloc
#define swf4alloc_ALREADY_DEFINED
#else
#define yyalloc swf4alloc
#endif

#ifdef yyrealloc
#define swf4realloc_ALREADY_DEFINED
#else
#define yyrealloc swf4realloc
#endif

#ifdef yyfree
#define swf4free_ALREADY_DEFINED
#else
#define yyfree swf4free
#endif

#ifdef yytext
#define swf4text_ALREADY_DEFINED
#else
#define yytext swf4text
#endif

#ifdef yyleng
#define swf4leng_ALREADY_DEFINED
#else
#define yyleng swf4leng
#endif

#ifdef yyin
#define swf4in_ALREADY_DEFINED
#else
#define yyin swf4in
#endif

#ifdef yyout
#define swf4out_ALREADY_DEFINED
#else
#define yyout swf4out
#endif

#ifdef yy_flex_debug
#define swf4_flex_debug_ALREADY_DEFINED
#else
#define yy_flex_debug swf4_flex_debug
#endif

#ifdef yylineno
#define swf4lineno_ALREADY_DEFINED
#else
#define yylineno swf4lineno
#endif

/* First, we deal with  platform-specific or compiler-specific issues. */

/* begin standard C headers. */
#include <stdio.h>
#include <string.h>
#include <errno.h>
#include <stdlib.h>

/* end standard C headers. */

/* flex integer type definitions */

#ifndef FLEXINT_H
#define FLEXINT_H

/* C99 systems have <inttypes.h>. Non-C99 systems may or may not. */

#if defined (__STDC_VERSION__) && __STDC_VERSION__ >= 199901L

/* C99 says to define __STDC_LIMIT_MACROS before including stdint.h,
 * if you want the limit (max/min) macros for int types. 
 */
#ifndef __STDC_LIMIT_MACROS
#define __STDC_LIMIT_MACROS 1
#endif

#include <inttypes.h>
typedef int8_t flex_int8_t;
typedef uint8_t flex_uint8_t;
typedef int16_t flex_int16_t;
typedef uint16_t flex_uint16_t;
typedef int32_t flex_int32_t;
typedef uint32_t flex_uint32_t;
#else
typedef signed char flex_int8_t;
typedef short int flex_int16_t;
typedef int flex_int32_t;
typedef unsigned char flex_uint8_t; 
typedef unsigned short int flex_uint16_t;
typedef unsigned int flex_uint32_t;

/* Limits of integral types. */
#ifndef INT8_MIN
#define INT8_MIN               (-128)
#endif
#ifndef INT16_MIN
#define INT16_MIN              (-32767-1)
#endif
#ifndef INT32_MIN
#define INT32_MIN              (-2147483647-1)
#endif
#ifndef INT8_MAX
#define INT8_MAX               (127)
#endif
#ifndef INT16_MAX
#define INT16_MAX              (32767)
#endif
#ifndef INT32_MAX
#define INT32_MAX              (2147483647)
#endif
#ifndef UINT8_MAX
#define UINT8_MAX              (255U)
#endif
#ifndef UINT16_MAX
#define UINT16_MAX             (65535U)
#endif
#ifndef UINT32_MAX
#define UINT32_MAX             (4294967295U)
#endif

#ifndef SIZE_MAX
#define SIZE_MAX               (~(size_t)0)
#endif

#endif /* ! C99 */

#endif /* ! FLEXINT_H */

/* begin standard C++ headers. */

/* TODO: this is always defined, so inline it */
#define yyconst const

#if defined(__GNUC__) && __GNUC__ >= 3
#define yynoreturn __attribute__((__noreturn__))
#else
#define yynoreturn
#endif

/* Returned upon end-of-file. */
#define YY_NULL 0

/* Promotes a possibly negative, possibly signed char to an
 *   integer in range [0..255] for use as an array index.
 */
#define YY_SC_TO_UI(c) ((YY_CHAR) (c))

/* Enter a start condition.  This macro really ought to take a parameter,
 * but we do it the disgusting crufty way forced on us by the ()-less
 * definition of BEGIN.
 */
#define BEGIN (yy_start) = 1 + 2 *
/* Translate the current start state into a value that can be later handed
 * to BEGIN to return to the state.  The YYSTATE alias is for lex
 * compatibility.
 */
#define YY_START (((yy_start) - 1) / 2)
#define YYSTATE YY_START
/* Action number for EOF rule of a given start state. */
#define YY_STATE_EOF(state) (YY_END_OF_BUFFER + state + 1)
/* Special action meaning "start processing a new file". */
#define YY_NEW_FILE yyrestart( yyin  )
#define YY_END_OF_BUFFER_CHAR 0

/* Size of default input buffer. */
#ifndef YY_BUF_SIZE
#ifdef __ia64__
/* On IA-64, the buffer size is 16k, not 8k.
 * Moreover, YY_BUF_SIZE is 2*YY_READ_BUF_SIZE in the general case.
 * Ditto for the __ia64__ case accordingly.
 */
#define YY_BUF_SIZE 32768
#else
#define YY_BUF_SIZE 16384
#endif /* __ia64__ */
#endif

/* The state buf must be large enough to hold one state per character in the main buffer.
 */
#define YY_STATE_BUF_SIZE   ((YY_BUF_SIZE + 2) * sizeof(yy_state_type))

#ifndef YY_TYPEDEF_YY_BUFFER_STATE
#define YY_TYPEDEF_YY_BUFFER_STATE
typedef struct yy_buffer_state *YY_BUFFER_STATE;
#endif

#ifndef YY_TYPEDEF_YY_SIZE_T
#define YY_TYPEDEF_YY_SIZE_T
typedef size_t yy_size_t;
#endif

extern int yyleng;

extern FILE *yyin, *yyout;

#define EOB_ACT_CONTINUE_SCAN 0
#define EOB_ACT_END_OF_FILE 1
#define EOB_ACT_LAST_MATCH 2
    
    #define YY_LESS_LINENO(n)
    #define YY_LINENO_REWIND_TO(ptr)
    
/* Return all but the first "n" matched characters back to the input stream. */
#define yyless(n) \
	do \
		{ \
		/* Undo effects of setting up yytext. */ \
        int yyless_macro_arg = (n); \
        YY_LESS_LINENO(yyless_macro_arg);\
		*yy_cp = (yy_hold_char); \
		YY_RESTORE_YY_MORE_OFFSET \
		(yy_c_buf_p) = yy_cp = yy_bp + yyless_macro_arg - YY_MORE_ADJ; \
		YY_DO_BEFORE_ACTION; /* set up yytext again */ \
		} \
	while ( 0 )
#define unput(c) yyunput( c, (yytext_ptr)  )

#ifndef YY_STRUCT_YY_BUFFER_STATE
#define YY_STRUCT_YY_BUFFER_STATE
struct yy_buffer_state
	{
	FILE *yy_input_file;

	char *yy_ch_buf;		/* input buffer */
	char *yy_buf_pos;		/* current position in input buffer */

	/* Size of input buffer in bytes, not including room for EOB
	 * characters.
	 */
	int yy_buf_size;

	/* Number of characters read into yy_ch_buf, not including EOB
	 * characters.
	 */
	int yy_n_chars;

	/* Whether we "own" the buffer - i.e., we know we created it,
	 * and can realloc() it to grow it, and should free() it to
	 * delete it.
	 */
	int yy_is_our_buffer;

	/* Whether this is an "interactive" input source; if so, and
	 * if we're using stdio for input, then we want to use getc()
	 * instead of fread(), to make sure we stop fetching input after
	 * each newline.
	 */
	int yy_is_interactive;

	/* Whether we're considered to be at the beginning of a line.
	 * If so, '^' rules will be active on the next match, otherwise
	 * not.
	 */
	int yy_at_bol;

    int yy_bs_lineno; /**< The line count. */
    int yy_bs_column; /**< The column count. */

	/* Whether to try to fill the input buffer when we reach the
	 * end of it.
	 */
	int yy_fill_buffer;

	int yy_buffer_status;

#define YY_BUFFER_NEW 0
#define YY_BUFFER_NORMAL 1
	/* When an EOF's been seen but there's still some text to process
	 * then we mark the buffer as YY_EOF_PENDING, to indicate that we
	 * shouldn't try reading from the input source any more.  We might
	 * still have a bunch of tokens to match, though, because of
	 * possible backing-up.
	 *
	 * When we actually see the EOF, we change the status to "new"
	 * (via yyrestart()), so that the user can continue scanning by
	 * just pointing yyin at a new input file.
	 */
#define YY_BUFFER_EOF_PENDING 2

	};
#endif /* !YY_STRUCT_YY_BUFFER_STATE */

/* Stack of input buffers. */
static size_t yy_buffer_stack_top = 0; /**< index of top of stack. */
static size_t yy_buffer_stack_max = 0; /**< capacity of stack. */
static YY_BUFFER_STATE * yy_buffer_stack = NULL; /**< Stack as an array. */

/* We provide macros for accessing buffer states in case in the
 * future we want to put the buffer states in a more general
 * "scanner state".
 *
 * Returns the top of the stack, or NULL.
 */
#define YY_CURRENT_BUFFER ( (yy_buffer_stack) \
                          ? (yy_buffer_stack)[(yy_buffer_stack_top)] \
                          : NULL)
/* Same as previous macro, but useful when we know that the buffer stack is not
 * NULL or when we need an lvalue. For internal use only.
 */
#define YY_CURRENT_BUFFER_LVALUE (yy_buffer_stack)[(yy_buffer_stack_top)]

/* yy_hold_char holds the character lost when yytext is formed. */
static char yy_hold_char;
static int yy_n_chars;		/* number of characters read into yy_ch_buf */
int yyleng;

/* Points to current character in buffer. */
static char *yy_c_buf_p = NULL;
static int yy_init = 0;		/* whether we need to initialize */
static int yy_start = 0;	/* start state number */

/* Flag which is used to allow yywrap()'s to do buffer switches
 * instead of setting up a fresh yyin.  A bit of a hack ...
 */
static int yy_did_buffer_switch_on_eof;

void yyrestart ( FILE *input_file  );
void yy_switch_to_buffer ( YY_BUFFER_STATE new_buffer  );
YY_BUFFER_STATE yy_create_buffer ( FILE *file, int size  );
void yy_delete_buffer ( YY_BUFFER_STATE b  );
void yy_flush_buffer ( YY_BUFFER_STATE b  );
void yypush_buffer_state ( YY_BUFFER_STATE new_buffer  );
void yypop_buffer_state ( void );

static void yyensure_buffer_stack ( void );
static void yy_load_buffer_state ( void );
static void yy_init_buffer ( YY_BUFFER_STATE b, FILE *file  );
#define YY_FLUSH_BUFFER yy_flush_buffer( YY_CURRENT_BUFFER )

YY_BUFFER_STATE yy_scan_buffer ( char *base, yy_size_t size  );
YY_BUFFER_STATE yy_scan_string ( const char *yy_str  );
YY_BUFFER_STATE yy_scan_bytes ( const char *bytes, int len  );

void *yyalloc ( yy_size_t  );
void *yyrealloc ( void *, yy_size_t  );
void yyfree ( void *  );

#define yy_new_buffer yy_create_buffer
#define yy_set_interactive(is_interactive) \
	{ \
	if ( ! YY_CURRENT_BUFFER ){ \
        yyensure_buffer_stack (); \
		YY_CURRENT_BUFFER_LVALUE =    \
            yy_create_buffer( yyin, YY_BUF_SIZE ); \
	} \
	YY_CURRENT_BUFFER_LVALUE->yy_is_interactive = is_interactive; \
	}
#define yy_set_bol(at_bol) \
	{ \
	if ( ! YY_CURRENT_BUFFER ){\
        yyensure_buffer_stack (); \
		YY_CURRENT_BUFFER_LVALUE =    \
            yy_create_buffer( yyin, YY_BUF_SIZE ); \
	} \
	YY_CURRENT_BUFFER_LVALUE->yy_at_bol = at_bol; \
	}
#define YY_AT_BOL() (YY_CURRENT_BUFFER_LVALUE->yy_at_bol)

/* Begin user sect3 */
typedef flex_uint8_t YY_CHAR;

FILE *yyin = NULL, *yyout = NULL;

typedef int yy_state_type;

extern int yylineno;
int yylineno = 1;

extern char *yytext;
#ifdef yytext_ptr
#undef yytext_ptr
#endif
#define yytext_ptr yytext

static yy_state_type yy_get_previous_state ( void );
static yy_state_type yy_try_NUL_trans ( yy_state_type current_state  );
static int yy_get_next_buffer ( void );
static void yynoreturn yy_fatal_error ( const char* msg  );

/* Done after the current pattern has been matched and before the
 * corresponding action - sets up yytext.
 */
#define YY_DO_BEFORE_ACTION \
	(yytext_ptr) = yy_bp; \
	yyleng = (int) (yy_cp - yy_bp); \
	(yy_hold_char) = *yy_cp; \
	*yy_cp = '\0'; \
	(yy_c_buf_p) = yy_cp;
#define YY_NUM_RULES 135
#define YY_END_OF_BUFFER 136
/* This struct is not used in this scanner,
   but its presence is necessary. */
struct yy_trans_info
	{
	flex_int32_t yy_verify;
	flex_int32_t yy_nxt;
	};
static const flex_int16_t yy_accept[611] =
    {   0,
        0,    0,    0,    0,  136,  134,   96,  133,  134,  122,
      134,   87,  119,  134,  123,  124,  120,  117,  129,  118,
      130,  121,    1,  132,  115,   99,  116,  100,  131,  125,
      126,   87,   87,   87,   87,   87,   87,   87,   87,   87,
       87,   87,   87,   87,   87,   87,   87,   87,  127,  134,
      128,   87,   87,   87,   87,   87,   87,   87,   87,   87,
       87,   87,   87,   87,  133,  104,    0,   92,   90,    0,
       87,    0,  105,    0,   93,   91,    0,  107,   97,  109,
       98,  110,  114,    0,   88,   94,   88,   95,  108,    2,
        1,  101,  103,  102,   87,   87,   87,   87,   87,   11,

       87,   87,   87,   87,   87,   87,   87,    9,   87,   87,
       87,   87,   87,   87,   87,   87,   87,   87,   87,   87,
       87,   87,   87,   87,   87,   87,   87,  106,   87,   87,
       87,   87,   87,   87,   87,   87,   87,   87,   87,   87,
       87,   87,   87,   87,   87,   87,   87,   87,   87,   87,
       87,   87,  112,   89,   89,   88,   88,    2,  113,  111,
       45,   87,   87,   24,   87,   87,   87,   87,    8,   87,
       87,   87,   16,   87,   87,   87,   23,   87,   87,   87,
       87,   87,   87,   87,   87,   87,   87,   87,   87,   87,
       87,   87,   87,   46,   87,   45,   87,   87,   87,   87,

       87,   87,   87,   87,   87,   87,   87,   87,   87,   87,
       87,   62,   87,   87,   87,   87,   87,   87,   87,   87,
       87,   89,   89,   87,   87,   87,   87,   87,    7,   87,
       87,   87,   87,   87,   87,   87,   87,   35,   87,   87,
       87,   87,   87,   36,   87,   87,   44,   14,   87,   87,
        3,   87,   87,   87,   87,   87,   69,   87,   87,   87,
       87,   87,   87,   87,   87,   87,   87,   71,   51,   87,
       87,   87,   87,   87,   63,   87,   87,   87,   87,   87,
       87,   87,   87,   87,   87,    5,   87,   87,   87,   87,
        4,   87,   87,   87,   87,   87,   87,   87,   87,   87,

       87,   87,   87,   87,   87,   87,   87,   87,   87,   87,
       20,   87,   10,   87,   70,   87,   87,   87,   87,   87,
       87,   87,   87,   87,   87,   87,   87,   87,   87,   87,
       87,   87,   87,   87,   87,   87,   87,   87,   87,   87,
       87,   87,   17,   87,   87,   87,   87,   26,   87,   87,
       15,   87,   87,   87,   87,   13,   87,   87,   87,   87,
       87,   31,   87,   87,   87,   87,   87,   87,   87,   48,
       87,   50,   87,   87,   26,   87,   87,   87,   87,   87,
       87,   87,   13,   87,   87,   87,   87,   87,   87,   31,
       87,   87,   87,   87,   87,   87,   87,   27,   87,   87,

       87,   87,   87,   87,   87,   87,   87,   87,   87,   87,
       87,   12,   87,   87,   87,   87,   83,   87,   84,   74,
       87,   87,   87,   87,   87,   87,   87,   87,   87,   87,
       87,   87,   87,   87,   87,   87,   87,   87,   87,   87,
        6,   87,   87,   87,   87,   87,   87,   87,   87,   87,
       87,   87,   87,   22,   87,   87,   87,   87,   86,   87,
       87,   87,   87,   87,   87,   87,   87,   87,   87,   87,
       49,   87,   87,   87,   87,   87,   87,   87,   87,   87,
       87,   87,   87,   87,   25,   87,   87,   87,   87,   39,
       28,   87,   33,   34,   87,   42,   21,   87,   87,   87,

       87,   87,   87,   87,   87,   87,   87,   87,   53,   87,
       87,   87,   87,   87,   87,   87,   87,   87,   80,   55,
       87,   87,   87,   87,   47,   66,   87,   87,   87,   87,
       87,   87,   87,   19,   38,   43,   87,   87,   87,   87,
       87,   87,   76,   52,   54,   87,   87,   87,   87,   87,
       87,   87,   79,   87,   87,   87,   87,   61,   87,   87,
       41,   32,   40,   87,   87,   87,   64,   65,   82,   75,
       72,   87,   87,   87,   87,   87,   87,   78,   73,   87,
       87,   87,   87,   87,   29,   87,   87,   87,   87,   87,
       87,   85,   77,   56,   87,   58,   87,   18,   30,   37,

       67,   68,   87,   87,   57,   81,   87,   60,   59,    0
    } ;

static const YY_CHAR yy_ec[256] =
    {   0,
        1,    1,    1,    1,    1,    1,    1,    1,    2,    3,
        2,    2,    4,    1,    1,    1,    1,    1,    1,    1,
        1,    1,    1,    1,    1,    1,    1,    1,    1,    1,
        1,    2,    5,    6,    1,    7,    1,    8,    9,   10,
       11,   12,   13,   14,   15,   16,   17,   18,   19,   20,
       18,   18,   18,   18,   18,   18,   18,   21,   22,   23,
       24,   25,   26,    1,   27,    7,   28,   29,    7,   30,
        7,    7,    7,    7,    7,   31,   32,   33,   34,   35,
       36,   37,   38,   39,   40,   41,    7,    7,    7,    7,
       42,   43,   44,    1,    7,    1,   45,   46,   47,   48,

       49,   50,   51,   52,   53,   54,   55,   56,   57,   58,
       59,   60,   61,   62,   63,   64,   65,   66,   67,   68,
       69,    7,   70,   71,   72,    1,    1,    1,    1,    1,
        1,    1,    1,    1,    1,    1,    1,    1,    1,    1,
        1,    1,    1,    1,    1,    1,    1,    1,    1,    1,
        1,    1,    1,    1,    1,    1,    1,    1,    1,    1,
        1,    1,    1,    1,    1,    1,    1,    1,    1,    1,
        1,    1,    1,    1,    1,    1,    1,    1,    1,    1,
        1,    1,    1,    1,    1,    1,    1,    1,    1,    1,
        1,    1,    1,    1,    1,    1,    1,    1,    1,    1,

        1,    1,    1,    1,    1,    1,    1,    1,    1,    1,
        1,    1,    1,    1,    1,    1,    1,    1,    1,    1,
        1,    1,    1,    1,    1,    1,    1,    1,    1,    1,
        1,    1,    1,    1,    1,    1,    1,    1,    1,    1,
        1,    1,    1,    1,    1,    1,    1,    1,    1,    1,
        1,    1,    1,    1,    1
    } ;

static const YY_CHAR yy_meta[73] =
    {   0,
        1,    1,    1,    1,    1,    1,    2,    1,    1,    1,
        1,    3,    1,    1,    1,    4,    5,    6,    6,    6,
        1,    1,    1,    3,    1,    1,    2,    2,    2,    2,
        2,    2,    2,    2,    2,    2,    2,    2,    2,    2,
        2,    1,    1,    1,    2,    2,    2,    2,    2,    2,
        2,    2,    2,    2,    2,    2,    2,    2,    2,    2,
        2,    2,    2,    2,    2,    2,    2,    2,    2,    1,
        1,    1
    } ;

static const flex_int16_t yy_base[618] =
    {   0,
        0,    0,   28,   51, 1267, 1268, 1268, 1268, 1263, 1241,
       77, 1247, 1255,   78, 1268, 1268, 1238,   65, 1268,   79,
       93,  100,  107, 1268, 1268, 1237, 1236, 1235, 1268, 1268,
     1268,   69,   57,   84,   76,   89,  105,  111,   80,  114,
      116,   87,  120,  117,  122,  131,  123,  125, 1268, 1187,
     1268,  137,  136,  138,  140,  130,  129,  155,  161,  157,
      182,  185,  189,  188, 1268, 1233,  209,  214, 1268, 1253,
     1238, 1238, 1268,  166,  215, 1268, 1250, 1268, 1268, 1268,
     1268, 1268, 1235,  213, 1234, 1268,  135, 1268, 1268,  225,
      243, 1225, 1225, 1268,  211,  204,  191,  193,  206, 1231,

      194,  215,  218,  219,  222,  229,  239, 1230,  243,  248,
      249,  252,  253,  254,  255,  256,  258,  259,  260,  262,
      265,  263,  267,  266,  268,  269,  273, 1268,  270,  275,
      271,  283,  272,  274,  281,  278,  280,  285,  279,  292,
      313,  294,  295,  293,  317,  318,  320,  321,  325,  329,
      330,  335, 1268, 1229,  142, 1228, 1227,  341, 1268, 1268,
     1226,  337,  339, 1225,  345,  346,  348,  331, 1224,  349,
      351,  352, 1223,  350,  355,  354, 1222,  356,  357,  362,
      361,  373,  372,  376,  379,  381,  382,  383,  387,  388,
      390,  391,  396, 1221,  397,  398,  402,  404,  405,  400,

      407,  409,  424,  410,  411,  412,  414,  413,  416,  423,
      427, 1220,  426,  429,  440,  443,  430,  432,  431,  444,
      448, 1219, 1218,  453,  456,  455,  457,  462, 1217,  464,
      476,  466,  479,  484,  463,  488,  487, 1216,  489,  478,
      480,  481,  501,  504,  505,  506, 1215, 1214,  507,  513,
     1213,  515,  517,  514,  518,  519,  521,  522,  523,  526,
      527,  531,  530,  532,  533,  535,  561, 1212, 1211,  536,
      537,  554,  538,  540, 1210,  539,  541,  542,  556,  558,
      544,  559,  560,  562,  565, 1209,  543,  573,  577,  580,
     1208,  579,  585,  589,  592,  595,  596,  597,  601,  599,

      602,  605,  604,  606,  127,  608,  612,  611,  613,  614,
     1207,  615, 1206,  616, 1205,  621,  617,  619,  623,  622,
      624,  625,  626,  634,  630,  635,  643,  638,  637,  642,
      652,  657,  658,  660,  661,  662,  669,  664,  668,  672,
      676,  677, 1204,  679,  683,  684,  685,  686,  689,  687,
     1203,  691,  692,  693,  694, 1202,  699,  696,  701,  703,
      708, 1201,  709,  714,  712,  716,  717,  723,  719, 1200,
      725, 1199,  724,  729,  732,  736,  738,  739,  741,  742,
      743,  744,  749,  752,  748,  753,  750,  755,  760,  757,
      768,  764,  765,  769,  770,  775,  774, 1198,  776,  771,

      779,  780,  773,  781,  793,  782,  795,  796,  797,  807,
      804, 1197,  810,  812,  808,  818, 1196,  819, 1195, 1194,
      820,  822,  825,  824,  826,  827,  828,  829,  831,  833,
      837,  836,  842,  834,  835,  846,  843,  849,  839,  850,
     1193,  855,  845,  847,  856,  857,  858,  860,  859,  883,
      884,  885,  893, 1192,  894,  896,  898,  899, 1191,  900,
      897,  901,  902,  903,  904,  905,  906,  907,  908,  909,
     1190,  910,  911,  912,  913,  914,  918,  922,  916,  919,
      917,  921,  924,  929, 1189,  944,  938,  937,  939, 1188,
      959,  942, 1187, 1186,  940, 1185, 1184,  954,  961,  923,

      965,  973,  972,  976,  977,  978,  979,  980, 1183,  982,
      985,  986,  988,  989,  990,  987,  991,  996, 1182, 1181,
      997,  995,  998,  992, 1180, 1179, 1001, 1002,  999, 1003,
     1004, 1005, 1006, 1178, 1177, 1176, 1007, 1013, 1011, 1014,
     1015, 1017, 1175, 1174, 1173, 1022, 1021, 1024, 1028, 1033,
     1036, 1039, 1172, 1042, 1048, 1044, 1050, 1171, 1052, 1054,
     1168, 1167, 1163, 1059, 1061, 1060, 1162, 1159, 1145, 1144,
     1134, 1066, 1062, 1063, 1068, 1064, 1073, 1131, 1129, 1070,
     1076, 1075, 1079, 1077, 1128, 1078, 1080, 1081, 1082, 1084,
     1086, 1127, 1125, 1123, 1088, 1122, 1100, 1121, 1119, 1117,

     1114, 1113, 1085, 1095, 1104, 1101, 1089, 1096,  144, 1268,
     1153, 1158, 1164, 1169, 1173, 1176, 1181
    } ;

static const flex_int16_t yy_def[618] =
    {   0,
      610,    1,    1,    1,  610,  610,  610,  610,  610,  610,
      611,  612,  610,  613,  610,  610,  610,  610,  610,  610,
      610,  614,  610,  610,  610,  610,  610,  610,  610,  610,
      610,  612,  612,  612,  612,  612,  612,  612,  612,  612,
      612,  612,  612,  612,  612,  612,  612,  612,  610,  610,
      610,  612,  612,  612,  612,  612,  612,  612,  612,  612,
      612,  612,  612,  612,  610,  610,  611,  611,  610,  611,
      612,  615,  610,  613,  613,  610,  613,  610,  610,  610,
      610,  610,  610,  614,  616,  610,  610,  610,  610,  610,
      610,  610,  610,  610,  612,  612,  612,  612,  612,  612,

      612,  612,  612,  612,  612,  612,  612,  612,  612,  612,
      612,  612,  612,  612,  612,  612,  612,  612,  612,  612,
      612,  612,  612,  612,  612,  612,  612,  610,  612,  612,
      612,  612,  612,  612,  612,  612,  612,  612,  612,  612,
      612,  612,  612,  612,  612,  612,  612,  612,  612,  612,
      612,  612,  610,  617,  610,  616,  610,  610,  610,  610,
      612,  612,  612,  612,  612,  612,  612,  612,  612,  612,
      612,  612,  612,  612,  612,  612,  612,  612,  612,  612,
      612,  612,  612,  612,  612,  612,  612,  612,  612,  612,
      612,  612,  612,  612,  612,  612,  612,  612,  612,  612,

      612,  612,  612,  612,  612,  612,  612,  612,  612,  612,
      612,  612,  612,  612,  612,  612,  612,  612,  612,  612,
      612,  617,  610,  612,  612,  612,  612,  612,  612,  612,
      612,  612,  612,  612,  612,  612,  612,  612,  612,  612,
      612,  612,  612,  612,  612,  612,  612,  612,  612,  612,
      612,  612,  612,  612,  612,  612,  612,  612,  612,  612,
      612,  612,  612,  612,  612,  612,  612,  612,  612,  612,
      612,  612,  612,  612,  612,  612,  612,  612,  612,  612,
      612,  612,  612,  612,  612,  612,  612,  612,  612,  612,
      612,  612,  612,  612,  612,  612,  612,  612,  612,  612,

      612,  612,  612,  612,  612,  612,  612,  612,  612,  612,
      612,  612,  612,  612,  612,  612,  612,  612,  612,  612,
      612,  612,  612,  612,  612,  612,  612,  612,  612,  612,
      612,  612,  612,  612,  612,  612,  612,  612,  612,  612,
      612,  612,  612,  612,  612,  612,  612,  612,  612,  612,
      612,  612,  612,  612,  612,  612,  612,  612,  612,  612,
      612,  612,  612,  612,  612,  612,  612,  612,  612,  612,
      612,  612,  612,  612,  612,  612,  612,  612,  612,  612,
      612,  612,  612,  612,  612,  612,  612,  612,  612,  612,
      612,  612,  612,  612,  612,  612,  612,  612,  612,  612,

      612,  612,  612,  612,  612,  612,  612,  612,  612,  612,
      612,  612,  612,  612,  612,  612,  612,  612,  612,  612,
      612,  612,  612,  612,  612,  612,  612,  612,  612,  612,
      612,  612,  612,  612,  612,  612,  612,  612,  612,  612,
      612,  612,  612,  612,  612,  612,  612,  612,  612,  612,
      612,  612,  612,  612,  612,  612,  612,  612,  612,  612,
      612,  612,  612,  612,  612,  612,  612,  612,  612,  612,
      612,  612,  612,  612,  612,  612,  612,  612,  612,  612,
      612,  612,  612,  612,  612,  612,  612,  612,  612,  612,
      612,  612,  612,  612,  612,  612,  612,  612,  612,  612,

      612,  612,  612,  612,  612,  612,  612,  612,  612,  612,
      612,  612,  612,  612,  612,  612,  612,  612,  612,  612,
      612,  612,  612,  612,  612,  612,  612,  612,  612,  612,
      612,  612,  612,  612,  612,  612,  612,  612,  612,  612,
      612,  612,  612,  612,  612,  612,  612,  612,  612,  612,
      612,  612,  612,  612,  612,  612,  612,  612,  612,  612,
      612,  612,  612,  612,  612,  612,  612,  612,  612,  612,
      612,  612,  612,  612,  612,  612,  612,  612,  612,  612,
      612,  612,  612,  612,  612,  612,  612,  612,  612,  612,
      612,  612,  612,  612,  612,  612,  612,  612,  612,  612,

      612,  612,  612,  612,  612,  612,  612,  612,  612,    0,
      610,  610,  610,  610,  610,  610,  610
    } ;

static const flex_int16_t yy_nxt[1341] =
    {   0,
        6,    7,    8,    9,   10,   11,   12,   13,   14,   15,
       16,   17,   18,   19,   20,   21,   22,   23,   23,   23,
       24,   25,   26,   27,   28,   29,   12,   12,   12,   12,
       12,   12,   12,   12,   12,   12,   12,   12,   12,   12,
       12,   30,    6,   31,   32,   33,   34,   35,   36,   37,
       38,   12,   39,   12,   12,   40,   12,   41,   42,   43,
       12,   44,   45,   46,   12,   47,   48,   12,   12,   49,
       50,   51,   52,   72,   53,   54,   55,   79,   56,   68,
       75,   57,   69,   58,   59,   72,   76,   60,   80,   61,
       62,   63,   72,   81,   64,   52,   72,   53,   54,   55,

       72,   56,   82,   72,   57,   72,   58,   59,   83,   84,
       60,   86,   61,   62,   63,   87,   88,   64,   96,   70,
       77,   72,   90,   89,   91,   91,   91,   72,   97,  108,
       72,   95,   72,   72,  100,   98,   72,  109,   72,   72,
      101,   72,   99,   72,  102,   72,   72,   72,  113,  103,
      157,   84,   72,   72,   72,  359,   72,  223,   72,  106,
       72,  116,  110,  104,  112,  117,  105,  126,   75,  107,
      118,   72,  111,   72,   76,  114,  127,   72,  137,  121,
      131,  115,  122,  123,  129,  119,  120,  132,  138,  124,
      134,  133,  125,  139,   99,  102,  100,  135,   72,  130,

      136,   72,  101,  140,   72,   72,  142,   72,   77,   72,
       72,   68,  114,  141,   69,  144,   68,   75,  115,   69,
       72,  145,   72,   76,  610,  143,  146,   72,   87,  610,
      147,   72,  152,  148,   72,   72,  610,  121,   72,  127,
      122,  123,  158,  158,  158,   72,  163,  151,  149,  150,
      125,   70,  162,  166,  164,   72,   70,   77,   90,   72,
       91,   91,   91,  165,   72,   72,  170,  161,   72,   72,
       72,   72,   72,  168,   72,   72,   72,  167,   72,   72,
      169,   72,   72,   72,   72,   72,   72,   72,   72,   72,
       72,   72,  171,  175,   72,   72,   72,   72,  178,   72,

      177,   72,  172,  179,  183,  174,  173,  185,   72,   72,
       72,   72,  190,  180,  181,  187,  189,  194,  184,  176,
      186,  195,  182,  188,  192,  193,  197,  198,  201,   72,
      199,  196,  191,   72,   72,  205,   72,   72,  208,  200,
      209,   72,  202,  203,  164,   72,   72,   72,  204,  174,
      211,   72,  212,   72,  206,   72,  210,  175,  158,  158,
      158,   72,   72,  207,   72,   72,   72,   72,   72,  217,
       72,   72,   72,   72,  219,  214,  215,   72,   72,  213,
      189,  224,  220,  184,  216,  232,  218,  221,   72,   72,
      233,  226,   72,  230,  225,   72,  229,   72,   72,   72,

      235,  228,  236,   72,   72,  231,   72,   72,  227,  240,
      234,  242,   72,   72,   72,  233,   72,  237,   72,  241,
       72,   72,  239,   72,  238,   72,   72,   72,   72,   72,
       72,  248,   72,  243,  250,  244,  246,  249,  251,   72,
       72,  245,   72,   72,  247,   72,   72,   72,   72,  254,
      255,  253,  260,  262,  261,  252,   72,  257,  232,   72,
       72,  256,  259,  233,   72,  258,  270,  272,  267,   72,
      268,   72,   72,   72,  269,  271,  276,  275,   72,   72,
       72,  242,   72,  263,  282,  287,  273,  264,  265,  266,
      274,  281,   72,  283,   72,   72,   72,   72,  277,  288,

       72,  284,  278,   72,   72,   72,  279,  286,  280,  289,
      295,  285,  291,  296,  290,  294,  300,   72,  301,  298,
       72,   72,   72,   72,  292,  304,  297,  293,  299,   72,
       72,   72,  306,   72,   72,   72,  302,   72,   72,   72,
      294,  307,   72,   72,  309,  303,   72,   72,   72,   72,
      287,   72,   72,   72,   72,   72,   72,   72,   72,   72,
       72,  311,  310,  312,  305,  313,  314,  315,  308,  294,
       72,  318,   72,  319,   72,   72,   72,   72,   72,  325,
      316,   72,  327,  328,  323,  317,  321,  295,  320,   72,
      296,  322,  331,   72,  324,   72,   72,  332,  329,  330,

      335,   72,  336,  334,  342,   72,  333,  337,   72,  346,
      326,   72,   72,   72,  341,   72,  338,   72,   72,  348,
       72,   72,   72,  339,   72,  340,  345,   72,   72,   72,
       72,   72,   72,   72,  344,   72,  343,   72,   72,   72,
       72,   72,   72,  347,  348,  353,   72,  351,  365,  349,
       72,   72,  357,   72,   72,  352,  350,  363,   72,   72,
      354,  356,  364,  355,  348,  367,  371,  358,   72,  360,
      361,  370,  362,   72,   72,  368,   72,   72,   72,  366,
       72,  369,  374,  373,   72,   72,  372,  378,   72,  375,
      379,  376,   72,   72,  381,   72,  377,  359,  380,   72,

       72,   72,   72,   72,  398,   72,  384,   72,   72,   72,
       72,  382,   72,  383,  389,   72,  388,   72,  385,   72,
      391,  393,  386,  387,   72,   72,  405,  395,   72,  390,
       72,  400,   72,   72,  392,   72,  399,  403,  404,   72,
       72,   72,  396,  394,  397,   72,  406,  408,   72,  411,
      398,  420,   72,  402,   72,   72,  401,   72,   72,   72,
       72,  412,  407,  414,   72,   72,   72,  415,   72,   72,
      410,   72,  409,   72,  413,  417,   72,  419,  416,  405,
       72,   72,  422,  418,   72,   72,   72,   72,  421,   72,
       72,   72,   72,  424,  423,   72,   72,   72,   72,  427,

      426,  437,  432,  431,  434,  425,  428,  430,  435,   72,
      445,   72,   72,   72,  429,  436,  433,  441,  438,  443,
       72,  440,  444,   72,   72,  439,   72,  446,   72,  449,
      452,  447,  448,  442,   72,   72,   72,  450,   72,  453,
       72,   72,   72,   72,   72,   72,  454,   72,  451,   72,
       72,   72,   72,   72,  455,   72,  458,  456,   72,   72,
      459,   72,   72,   72,  463,   72,   72,  462,  457,  465,
      460,   72,   72,   72,   72,   72,   72,  470,  464,  461,
      476,  474,  466,  467,  469,  475,  477,  468,  484,  482,
      473,  478,  487,  472,  481,  479,  471,  483,  485,   72,

       72,   72,  480,  486,  492,  490,  491,  493,  488,   72,
       72,  489,   72,   72,   72,   72,   72,   72,   72,   72,
       72,   72,   72,   72,   72,   72,   72,   72,   72,   72,
       72,  494,   72,   72,   72,   72,  495,   72,   72,   72,
       72,  498,  500,  497,  499,   72,  502,  505,  496,  503,
      501,  506,  511,   72,   72,   72,   72,  512,   72,  518,
       72,  507,  504,  508,  513,  510,  514,  509,  519,  520,
       72,  528,  515,  516,  523,   72,  517,   72,  537,  524,
      521,   72,  522,  531,  525,  526,  529,  533,   72,   72,
      527,  532,   72,   72,   72,   72,   72,  543,   72,  534,

      530,   72,   72,   72,   72,   72,   72,   72,   72,  538,
      553,   72,   72,   72,   72,   72,  535,   72,   72,   72,
       72,   72,   72,   72,  536,  539,  544,   72,  546,   72,
       72,   72,  542,   72,  550,  540,  549,   72,   72,  541,
       72,  555,  551,  545,   72,  559,  561,  547,  557,   72,
      552,  554,   72,  548,  558,   72,  556,  560,   72,  566,
       72,  565,  569,  568,   72,  571,   72,  573,   72,  564,
       72,  562,  563,  572,  567,   72,   72,   72,   72,   72,
       72,  576,   72,  570,   72,  575,   72,  574,  581,   72,
      579,   72,   72,   72,   72,   72,   72,   72,   72,  577,

       72,   72,   72,  580,   72,   72,  584,  578,  583,  586,
      588,   72,   72,  582,  589,  585,   72,   72,  591,  606,
       72,  593,  595,  587,  590,  592,  596,  597,  603,   72,
       72,  607,  594,   72,  602,   72,  598,   72,   72,   72,
      599,   72,  601,   72,   72,   72,  608,   72,  600,  604,
       72,  605,  609,   67,   67,   67,   67,   67,   67,   71,
       72,   72,   71,   71,   74,   74,   74,   74,   74,   74,
       85,   85,   85,   85,  154,   72,  154,  156,   72,   72,
      156,  156,  222,   72,   72,  222,  222,   72,   72,   72,
       72,   72,   72,   72,   72,   72,   72,   72,   72,   72,

       72,   72,   72,   72,   72,   72,   72,   72,   72,   72,
       72,   72,   72,   72,   72,   72,   72,   72,   72,   72,
       72,   72,   72,   72,   72,   72,   72,   72,   72,   72,
       72,   72,   72,   72,   72,   72,   72,   72,   72,   72,
       72,   72,   72,   84,   84,   72,   72,   72,  160,  159,
       84,   84,  610,  155,   72,  610,  153,  128,   94,   93,
       92,   78,   73,   72,   66,   65,  610,    5,  610,  610,
      610,  610,  610,  610,  610,  610,  610,  610,  610,  610,
      610,  610,  610,  610,  610,  610,  610,  610,  610,  610,
      610,  610,  610,  610,  610,  610,  610,  610,  610,  610,

      610,  610,  610,  610,  610,  610,  610,  610,  610,  610,
      610,  610,  610,  610,  610,  610,  610,  610,  610,  610,
      610,  610,  610,  610,  610,  610,  610,  610,  610,  610,
      610,  610,  610,  610,  610,  610,  610,  610,  610,  610
    } ;

static const flex_int16_t yy_chk[1341] =
    {   0,
        1,    1,    1,    1,    1,    1,    1,    1,    1,    1,
        1,    1,    1,    1,    1,    1,    1,    1,    1,    1,
        1,    1,    1,    1,    1,    1,    1,    1,    1,    1,
        1,    1,    1,    1,    1,    1,    1,    1,    1,    1,
        1,    1,    1,    1,    1,    1,    1,    1,    1,    1,
        1,    1,    1,    1,    1,    1,    1,    1,    1,    1,
        1,    1,    1,    1,    1,    1,    1,    1,    1,    1,
        1,    1,    3,   33,    3,    3,    3,   18,    3,   11,
       14,    3,   11,    3,    3,   32,   14,    3,   18,    3,
        3,    3,   35,   20,    3,    4,   39,    4,    4,    4,

       34,    4,   20,   42,    4,   36,    4,    4,   21,   21,
        4,   22,    4,    4,    4,   22,   22,    4,   33,   11,
       14,   37,   23,   22,   23,   23,   23,   38,   34,   39,
       40,   32,   41,   44,   35,   34,   43,   39,   45,   47,
       35,   48,   34,  305,   36,   57,   56,   46,   42,   37,
       87,   87,   53,   52,   54,  305,   55,  155,  155,   38,
      609,   44,   40,   37,   41,   44,   37,   47,   74,   38,
       45,   58,   40,   60,   74,   43,   48,   59,   56,   46,
       53,   43,   46,   46,   52,   45,   45,   53,   56,   46,
       54,   53,   46,   57,   53,   55,   54,   55,   61,   52,

       55,   62,   54,   58,   64,   63,   59,   97,   74,   98,
      101,   67,   60,   58,   67,   60,   68,   75,   60,   68,
       96,   60,   99,   75,   84,   59,   61,   95,   84,   84,
       61,  102,   64,   62,  103,  104,   84,   63,  105,   64,
       63,   63,   90,   90,   90,  106,   97,   63,   62,   62,
       63,   67,   96,  101,   98,  107,   68,   75,   91,  109,
       91,   91,   91,   99,  110,  111,  105,   95,  112,  113,
      114,  115,  116,  103,  117,  118,  119,  102,  120,  122,
      104,  121,  124,  123,  125,  126,  129,  131,  133,  127,
      134,  130,  106,  111,  136,  139,  137,  135,  114,  132,

      113,  138,  107,  115,  119,  110,  109,  120,  140,  144,
      142,  143,  125,  116,  117,  122,  124,  129,  119,  112,
      121,  130,  118,  123,  126,  127,  131,  132,  135,  141,
      133,  130,  125,  145,  146,  139,  147,  148,  142,  134,
      142,  149,  136,  137,  132,  150,  151,  168,  138,  140,
      143,  152,  144,  162,  140,  163,  142,  141,  158,  158,
      158,  165,  166,  141,  167,  170,  174,  171,  172,  149,
      176,  175,  178,  179,  150,  146,  147,  181,  180,  145,
      151,  162,  151,  149,  148,  171,  149,  152,  183,  182,
      171,  165,  184,  168,  163,  185,  167,  186,  187,  188,

      174,  166,  175,  189,  190,  170,  191,  192,  165,  180,
      172,  182,  193,  195,  196,  171,  200,  176,  197,  181,
      198,  199,  179,  201,  178,  202,  204,  205,  206,  208,
      207,  188,  209,  183,  190,  184,  186,  189,  191,  210,
      203,  185,  213,  211,  187,  214,  217,  219,  218,  195,
      196,  193,  200,  202,  201,  192,  215,  197,  203,  216,
      220,  196,  199,  203,  221,  198,  207,  209,  204,  224,
      205,  226,  225,  227,  206,  208,  214,  213,  228,  235,
      230,  216,  232,  203,  218,  225,  210,  203,  203,  203,
      211,  217,  231,  219,  240,  233,  241,  242,  215,  226,

      234,  220,  216,  237,  236,  239,  216,  224,  216,  227,
      234,  221,  230,  234,  228,  233,  237,  243,  239,  236,
      244,  245,  246,  249,  231,  242,  235,  232,  236,  250,
      254,  252,  244,  253,  255,  256,  240,  257,  258,  259,
      233,  244,  260,  261,  246,  241,  263,  262,  264,  265,
      257,  266,  270,  271,  273,  276,  274,  277,  278,  287,
      281,  250,  249,  252,  243,  253,  254,  255,  245,  265,
      272,  259,  279,  260,  280,  282,  283,  267,  284,  266,
      256,  285,  270,  271,  264,  258,  262,  267,  261,  288,
      267,  263,  274,  289,  265,  292,  290,  276,  272,  273,

      279,  293,  280,  278,  287,  294,  277,  281,  295,  292,
      267,  296,  297,  298,  285,  300,  282,  299,  301,  294,
      303,  302,  304,  283,  306,  284,  290,  308,  307,  309,
      310,  312,  314,  317,  289,  318,  288,  316,  320,  319,
      321,  322,  323,  293,  294,  299,  325,  297,  312,  295,
      324,  326,  303,  329,  328,  298,  296,  309,  330,  327,
      300,  302,  310,  301,  324,  316,  320,  304,  331,  306,
      307,  319,  308,  332,  333,  317,  334,  335,  336,  314,
      338,  318,  323,  322,  339,  337,  321,  327,  340,  324,
      328,  325,  341,  342,  330,  344,  326,  337,  329,  345,

      346,  347,  348,  350,  348,  349,  333,  352,  353,  354,
      355,  331,  358,  332,  338,  357,  337,  359,  334,  360,
      340,  342,  335,  336,  361,  363,  357,  345,  365,  339,
      364,  350,  366,  367,  341,  369,  349,  354,  355,  368,
      373,  371,  346,  344,  347,  374,  358,  360,  375,  364,
      375,  375,  376,  353,  377,  378,  352,  379,  380,  381,
      382,  365,  359,  367,  385,  383,  387,  368,  384,  386,
      363,  388,  361,  390,  366,  371,  389,  374,  369,  384,
      392,  393,  377,  373,  391,  394,  395,  400,  376,  403,
      397,  396,  399,  379,  378,  401,  402,  404,  406,  382,

      381,  390,  387,  386,  389,  380,  383,  385,  389,  405,
      399,  407,  408,  409,  384,  389,  388,  394,  391,  396,
      411,  393,  397,  410,  415,  392,  413,  400,  414,  403,
      406,  401,  402,  395,  416,  418,  421,  404,  422,  407,
      424,  423,  425,  426,  427,  428,  408,  429,  405,  430,
      434,  435,  432,  431,  409,  439,  413,  410,  433,  437,
      414,  443,  436,  444,  421,  438,  440,  418,  411,  423,
      415,  442,  445,  446,  447,  449,  448,  426,  422,  416,
      432,  430,  423,  423,  425,  431,  433,  424,  439,  437,
      429,  434,  443,  428,  436,  435,  427,  438,  440,  450,

      451,  452,  435,  442,  448,  446,  447,  449,  444,  453,
      455,  445,  456,  461,  457,  458,  460,  462,  463,  464,
      465,  466,  467,  468,  469,  470,  472,  473,  474,  475,
      476,  450,  479,  481,  477,  480,  451,  482,  478,  500,
      483,  455,  457,  453,  456,  484,  460,  463,  452,  461,
      458,  464,  469,  488,  487,  489,  495,  470,  492,  476,
      486,  465,  462,  466,  470,  468,  472,  467,  477,  478,
      498,  486,  473,  474,  481,  491,  475,  499,  500,  481,
      479,  501,  480,  489,  482,  483,  487,  492,  503,  502,
      484,  491,  504,  505,  506,  507,  508,  506,  510,  495,

      488,  511,  512,  516,  513,  514,  515,  517,  524,  501,
      517,  522,  518,  521,  523,  529,  498,  527,  528,  530,
      531,  532,  533,  537,  499,  502,  507,  539,  510,  538,
      540,  541,  505,  542,  514,  503,  513,  547,  546,  504,
      548,  521,  515,  508,  549,  527,  529,  511,  523,  550,
      516,  518,  551,  512,  524,  552,  522,  528,  554,  537,
      556,  533,  540,  539,  555,  542,  557,  547,  559,  532,
      560,  530,  531,  546,  538,  564,  566,  565,  573,  574,
      576,  550,  572,  541,  575,  549,  580,  548,  556,  577,
      554,  582,  581,  584,  586,  583,  587,  588,  589,  551,

      590,  603,  591,  555,  595,  607,  560,  552,  559,  565,
      572,  604,  608,  557,  573,  564,  597,  606,  575,  597,
      605,  577,  581,  566,  574,  576,  582,  583,  590,  602,
      601,  603,  580,  600,  589,  599,  584,  598,  596,  594,
      586,  593,  588,  592,  585,  579,  604,  578,  587,  591,
      571,  595,  607,  611,  611,  611,  611,  611,  611,  612,
      570,  569,  612,  612,  613,  613,  613,  613,  613,  613,
      614,  614,  614,  614,  615,  568,  615,  616,  567,  563,
      616,  616,  617,  562,  561,  617,  617,  558,  553,  545,
      544,  543,  536,  535,  534,  526,  525,  520,  519,  509,

      497,  496,  494,  493,  490,  485,  471,  459,  454,  441,
      420,  419,  417,  412,  398,  372,  370,  362,  356,  351,
      343,  315,  313,  311,  291,  286,  275,  269,  268,  251,
      248,  247,  238,  229,  223,  222,  212,  194,  177,  173,
      169,  164,  161,  157,  156,  154,  108,  100,   93,   92,
       85,   83,   77,   72,   71,   70,   66,   50,   28,   27,
       26,   17,   13,   12,   10,    9,    5,  610,  610,  610,
      610,  610,  610,  610,  610,  610,  610,  610,  610,  610,
      610,  610,  610,  610,  610,  610,  610,  610,  610,  610,
      610,  610,  610,  610,  610,  610,  610,  610,  610,  610,

      610,  610,  610,  610,  610,  610,  610,  610,  610,  610,
      610,  610,  610,  610,  610,  610,  610,  610,  610,  610,
      610,  610,  610,  610,  610,  610,  610,  610,  610,  610,
      610,  610,  610,  610,  610,  610,  610,  610,  610,  610
    } ;

static yy_state_type yy_last_accepting_state;
static char *yy_last_accepting_cpos;

extern int yy_flex_debug;
int yy_flex_debug = 0;

/* The intent behind this definition is that it'll catch
 * any uses of REJECT which flex missed.
 */
#define REJECT reject_used_but_not_detected
#define yymore() yymore_used_but_not_detected
#define YY_MORE_ADJ 0
#define YY_RESTORE_YY_MORE_OFFSET
char *yytext;
#line 1 "/usr/src/ports/ming/ming-0.4.8-2.x86_64/src/libming-ming-0_4_8/src/actioncompiler/swf4compiler.flex"
#line 2 "/usr/src/ports/ming/ming-0.4.8-2.x86_64/src/libming-ming-0_4_8/src/actioncompiler/swf4compiler.flex"

#include <math.h>
#include <string.h>
#include <stdlib.h>

#include "compile.h"
#include "actiontypes.h"
#include "blocks/error.h"
#include "swf4compiler.tab.h" /* defines token types */

int swf4debug;

static const char *lexBuffer = NULL;
static int lexBufferLen = 0;

static int  sLineNumber = 0;
static char szLine[1024];
static char msgbufs[2][1024] = { {0}, {0} }, *msgline = {0};
static int  column = 0;

static void comment();
static void comment1();
static void count();
static void warning(char *msg);

#define YY_INPUT(buf,result,max_size) result=lexBufferInput(buf, max_size)
#define YY_NO_UNISTD_H
#define YY_USE_PROTOS

/* thanks to the prolific and brilliant Raff: */
static int lexBufferInput(char *buf, int max_size)
{
  int l = lexBufferLen > max_size ? max_size : lexBufferLen;
  
  if (lexBufferLen <= 0)
    return YY_NULL;

  memcpy(buf, lexBuffer, l);
  lexBuffer += l;
  lexBufferLen -= l;
  return l;
}

static void unescape(char *buf)
{
  char *r, *w;

  r=buf; // read
  w=buf; // write
  while (*r)
  {
	if ( *r == '\\' )
	{
		r++;
		switch(*r)
		{
			case 'b' : *w = '\b'; break;
			case 'f' : *w = '\f'; break;
			case 'n' : *w = '\n'; break;
			case 'r' : *w = '\r'; break;
			case 't' : *w = '\t'; break;
			case 'x' :
			case 'u' : fprintf(stderr,"unsupported escape sequence\n");
		}
		w++;
		r++;
	}
	else
	{
		*w++ = *r++;
	}
  }
  *w='\0';
}

void swf4ParseInit(const char *script, int debug, int version)
{
  yyrestart(NULL);

  swf4debug = debug;

  lexBuffer = script;
  lexBufferLen = strlen(script);
  sLineNumber = 0;
  column = 0;
  msgline = msgbufs[0];
  swfVersion = version;
}

#line 1288 "lex.swf4.c"

#line 96 "/usr/src/ports/ming/ming-0.4.8-2.x86_64/src/libming-ming-0_4_8/src/actioncompiler/swf4compiler.flex"
 // forward declaration needed by the following function
#ifndef YY_PROTO
#ifdef YY_USE_PROTOS
#define YY_PROTO(proto) proto
#else
#define YY_PROTO(proto) ()
#endif
#endif
 static void yyunput YY_PROTO(( int c, char *buf_ptr ));

 void do_unput4(const char c) { unput(c); }
#line 1302 "lex.swf4.c"
#line 1303 "lex.swf4.c"

#define INITIAL 0
#define asm 1

#ifndef YY_NO_UNISTD_H
/* Special case for "unistd.h", since it is non-ANSI. We include it way
 * down here because we want the user's section 1 to have been scanned first.
 * The user has a chance to override it with an option.
 */
#include <unistd.h>
#endif

#ifndef YY_EXTRA_TYPE
#define YY_EXTRA_TYPE void *
#endif

static int yy_init_globals ( void );

/* Accessor methods to globals.
   These are made visible to non-reentrant scanners for convenience. */

int yylex_destroy ( void );

int yyget_debug ( void );

void yyset_debug ( int debug_flag  );

YY_EXTRA_TYPE yyget_extra ( void );

void yyset_extra ( YY_EXTRA_TYPE user_defined  );

FILE *yyget_in ( void );

void yyset_in  ( FILE * _in_str  );

FILE *yyget_out ( void );

void yyset_out  ( FILE * _out_str  );

			int yyget_leng ( void );

char *yyget_text ( void );

int yyget_lineno ( void );

void yyset_lineno ( int _line_number  );

/* Macros after this point can all be overridden by user definitions in
 * section 1.
 */

#ifndef YY_SKIP_YYWRAP
#ifdef __cplusplus
extern "C" int yywrap ( void );
#else
extern int yywrap ( void );
#endif
#endif

#ifndef YY_NO_UNPUT
    
    static void yyunput ( int c, char *buf_ptr  );
    
#endif

#ifndef yytext_ptr
static void yy_flex_strncpy ( char *, const char *, int );
#endif

#ifdef YY_NEED_STRLEN
static int yy_flex_strlen ( const char * );
#endif

#ifndef YY_NO_INPUT
#ifdef __cplusplus
static int yyinput ( void );
#else
static int input ( void );
#endif

#endif

/* Amount of stuff to slurp up with each read. */
#ifndef YY_READ_BUF_SIZE
#ifdef __ia64__
/* On IA-64, the buffer size is 16k, not 8k */
#define YY_READ_BUF_SIZE 16384
#else
#define YY_READ_BUF_SIZE 8192
#endif /* __ia64__ */
#endif

/* Copy whatever the last rule matched to the standard output. */
#ifndef ECHO
/* This used to be an fputs(), but since the string might contain NUL's,
 * we now use fwrite().
 */
#define ECHO do { if (fwrite( yytext, (size_t) yyleng, 1, yyout )) {} } while (0)
#endif

/* Gets input and stuffs it into "buf".  number of characters read, or YY_NULL,
 * is returned in "result".
 */
#ifndef YY_INPUT
#define YY_INPUT(buf,result,max_size) \
	if ( YY_CURRENT_BUFFER_LVALUE->yy_is_interactive ) \
		{ \
		int c = '*'; \
		int n; \
		for ( n = 0; n < max_size && \
			     (c = getc( yyin )) != EOF && c != '\n'; ++n ) \
			buf[n] = (char) c; \
		if ( c == '\n' ) \
			buf[n++] = (char) c; \
		if ( c == EOF && ferror( yyin ) ) \
			YY_FATAL_ERROR( "input in flex scanner failed" ); \
		result = n; \
		} \
	else \
		{ \
		errno=0; \
		while ( (result = (int) fread(buf, 1, (yy_size_t) max_size, yyin)) == 0 && ferror(yyin)) \
			{ \
			if( errno != EINTR) \
				{ \
				YY_FATAL_ERROR( "input in flex scanner failed" ); \
				break; \
				} \
			errno=0; \
			clearerr(yyin); \
			} \
		}\
\

#endif

/* No semi-colon after return; correct usage is to write "yyterminate();" -
 * we don't want an extra ';' after the "return" because that will cause
 * some compilers to complain about unreachable statements.
 */
#ifndef yyterminate
#define yyterminate() return YY_NULL
#endif

/* Number of entries by which start-condition stack grows. */
#ifndef YY_START_STACK_INCR
#define YY_START_STACK_INCR 25
#endif

/* Report a fatal error. */
#ifndef YY_FATAL_ERROR
#define YY_FATAL_ERROR(msg) yy_fatal_error( msg )
#endif

/* end tables serialization structures and prototypes */

/* Default declaration of generated scanner - a define so the user can
 * easily add parameters.
 */
#ifndef YY_DECL
#define YY_DECL_IS_OURS 1

extern int yylex (void);

#define YY_DECL int yylex (void)
#endif /* !YY_DECL */

/* Code executed at the beginning of each rule, after yytext and yyleng
 * have been set up.
 */
#ifndef YY_USER_ACTION
#define YY_USER_ACTION
#endif

/* Code executed at the end of each rule. */
#ifndef YY_BREAK
#define YY_BREAK /*LINTED*/break;
#endif

#define YY_RULE_SETUP \
	YY_USER_ACTION

/** The main scanner function which does all the work.
 */
YY_DECL
{
	yy_state_type yy_current_state;
	char *yy_cp, *yy_bp;
	int yy_act;
    
	if ( !(yy_init) )
		{
		(yy_init) = 1;

#ifdef YY_USER_INIT
		YY_USER_INIT;
#endif

		if ( ! (yy_start) )
			(yy_start) = 1;	/* first start state */

		if ( ! yyin )
			yyin = stdin;

		if ( ! yyout )
			yyout = stdout;

		if ( ! YY_CURRENT_BUFFER ) {
			yyensure_buffer_stack ();
			YY_CURRENT_BUFFER_LVALUE =
				yy_create_buffer( yyin, YY_BUF_SIZE );
		}

		yy_load_buffer_state(  );
		}

	{
#line 113 "/usr/src/ports/ming/ming-0.4.8-2.x86_64/src/libming-ming-0_4_8/src/actioncompiler/swf4compiler.flex"


#line 1524 "lex.swf4.c"

	while ( /*CONSTCOND*/1 )		/* loops until end-of-file is reached */
		{
		yy_cp = (yy_c_buf_p);

		/* Support of yytext. */
		*yy_cp = (yy_hold_char);

		/* yy_bp points to the position in yy_ch_buf of the start of
		 * the current run.
		 */
		yy_bp = yy_cp;

		yy_current_state = (yy_start);
yy_match:
		do
			{
			YY_CHAR yy_c = yy_ec[YY_SC_TO_UI(*yy_cp)] ;
			if ( yy_accept[yy_current_state] )
				{
				(yy_last_accepting_state) = yy_current_state;
				(yy_last_accepting_cpos) = yy_cp;
				}
			while ( yy_chk[yy_base[yy_current_state] + yy_c] != yy_current_state )
				{
				yy_current_state = (int) yy_def[yy_current_state];
				if ( yy_current_state >= 611 )
					yy_c = yy_meta[yy_c];
				}
			yy_current_state = yy_nxt[yy_base[yy_current_state] + yy_c];
			++yy_cp;
			}
		while ( yy_current_state != 610 );
		yy_cp = (yy_last_accepting_cpos);
		yy_current_state = (yy_last_accepting_state);

yy_find_action:
		yy_act = yy_accept[yy_current_state];

		YY_DO_BEFORE_ACTION;

do_action:	/* This label is used only to access EOF actions. */

		switch ( yy_act )
	{ /* beginning of action switch */
			case 0: /* must back up */
			/* undo the effects of YY_DO_BEFORE_ACTION */
			*yy_cp = (yy_hold_char);
			yy_cp = (yy_last_accepting_cpos);
			yy_current_state = (yy_last_accepting_state);
			goto yy_find_action;

case 1:
YY_RULE_SETUP
#line 115 "/usr/src/ports/ming/ming-0.4.8-2.x86_64/src/libming-ming-0_4_8/src/actioncompiler/swf4compiler.flex"
{ count();	swf4lval.str = strdup(yytext);
					return NUMBER; 		}
	YY_BREAK
case 2:
YY_RULE_SETUP
#line 117 "/usr/src/ports/ming/ming-0.4.8-2.x86_64/src/libming-ming-0_4_8/src/actioncompiler/swf4compiler.flex"
{ count();	swf4lval.str = strdup(yytext);
					return NUMBER; 		}
	YY_BREAK
case 3:
YY_RULE_SETUP
#line 119 "/usr/src/ports/ming/ming-0.4.8-2.x86_64/src/libming-ming-0_4_8/src/actioncompiler/swf4compiler.flex"
{ count();	swf4lval.str = strdup("1");
					return NUMBER;		}
	YY_BREAK
case 4:
YY_RULE_SETUP
#line 121 "/usr/src/ports/ming/ming-0.4.8-2.x86_64/src/libming-ming-0_4_8/src/actioncompiler/swf4compiler.flex"
{ count();	swf4lval.str = strdup("0");
					return NUMBER;		}
	YY_BREAK
case 5:
YY_RULE_SETUP
#line 123 "/usr/src/ports/ming/ming-0.4.8-2.x86_64/src/libming-ming-0_4_8/src/actioncompiler/swf4compiler.flex"
{ count();	return BREAK;		}
	YY_BREAK
case 6:
YY_RULE_SETUP
#line 124 "/usr/src/ports/ming/ming-0.4.8-2.x86_64/src/libming-ming-0_4_8/src/actioncompiler/swf4compiler.flex"
{ count();	return CONTINUE;	}
	YY_BREAK
case 7:
YY_RULE_SETUP
#line 125 "/usr/src/ports/ming/ming-0.4.8-2.x86_64/src/libming-ming-0_4_8/src/actioncompiler/swf4compiler.flex"
{ count();	return ELSE;		}
	YY_BREAK
case 8:
YY_RULE_SETUP
#line 126 "/usr/src/ports/ming/ming-0.4.8-2.x86_64/src/libming-ming-0_4_8/src/actioncompiler/swf4compiler.flex"
{ count();	return FOR;		}
	YY_BREAK
case 9:
YY_RULE_SETUP
#line 127 "/usr/src/ports/ming/ming-0.4.8-2.x86_64/src/libming-ming-0_4_8/src/actioncompiler/swf4compiler.flex"
{ count();	return IF;		}
	YY_BREAK
case 10:
YY_RULE_SETUP
#line 128 "/usr/src/ports/ming/ming-0.4.8-2.x86_64/src/libming-ming-0_4_8/src/actioncompiler/swf4compiler.flex"
{ count();	return WHILE;		}
	YY_BREAK
case 11:
YY_RULE_SETUP
#line 129 "/usr/src/ports/ming/ming-0.4.8-2.x86_64/src/libming-ming-0_4_8/src/actioncompiler/swf4compiler.flex"
{ count();	return DO;		}
	YY_BREAK
case 12:
YY_RULE_SETUP
#line 130 "/usr/src/ports/ming/ming-0.4.8-2.x86_64/src/libming-ming-0_4_8/src/actioncompiler/swf4compiler.flex"
{ count(); 	return EVAL;		}
	YY_BREAK
/* functions */
case 13:
YY_RULE_SETUP
#line 133 "/usr/src/ports/ming/ming-0.4.8-2.x86_64/src/libming-ming-0_4_8/src/actioncompiler/swf4compiler.flex"
{ count();	return RANDOM;	}
	YY_BREAK
case 14:
YY_RULE_SETUP
#line 134 "/usr/src/ports/ming/ming-0.4.8-2.x86_64/src/libming-ming-0_4_8/src/actioncompiler/swf4compiler.flex"
{ count();	return TIME;	}
	YY_BREAK
case 15:
YY_RULE_SETUP
#line 135 "/usr/src/ports/ming/ming-0.4.8-2.x86_64/src/libming-ming-0_4_8/src/actioncompiler/swf4compiler.flex"
{ count();	return LENGTH;	}
	YY_BREAK
case 16:
YY_RULE_SETUP
#line 136 "/usr/src/ports/ming/ming-0.4.8-2.x86_64/src/libming-ming-0_4_8/src/actioncompiler/swf4compiler.flex"
{ count();	return INT;	}
	YY_BREAK
case 17:
YY_RULE_SETUP
#line 137 "/usr/src/ports/ming/ming-0.4.8-2.x86_64/src/libming-ming-0_4_8/src/actioncompiler/swf4compiler.flex"
{ count();	return CONCAT;	}
	YY_BREAK
case 18:
YY_RULE_SETUP
#line 138 "/usr/src/ports/ming/ming-0.4.8-2.x86_64/src/libming-ming-0_4_8/src/actioncompiler/swf4compiler.flex"
{ count();	return DUPLICATECLIP;	}
	YY_BREAK
case 19:
YY_RULE_SETUP
#line 139 "/usr/src/ports/ming/ming-0.4.8-2.x86_64/src/libming-ming-0_4_8/src/actioncompiler/swf4compiler.flex"
{ count();	return REMOVECLIP;	}
	YY_BREAK
case 20:
YY_RULE_SETUP
#line 140 "/usr/src/ports/ming/ming-0.4.8-2.x86_64/src/libming-ming-0_4_8/src/actioncompiler/swf4compiler.flex"
{ count();	return TRACE;	}
	YY_BREAK
case 21:
YY_RULE_SETUP
#line 141 "/usr/src/ports/ming/ming-0.4.8-2.x86_64/src/libming-ming-0_4_8/src/actioncompiler/swf4compiler.flex"
{ count();	return STARTDRAG;	}
	YY_BREAK
case 22:
YY_RULE_SETUP
#line 142 "/usr/src/ports/ming/ming-0.4.8-2.x86_64/src/libming-ming-0_4_8/src/actioncompiler/swf4compiler.flex"
{ count();	return STOPDRAG;	}
	YY_BREAK
case 23:
YY_RULE_SETUP
#line 143 "/usr/src/ports/ming/ming-0.4.8-2.x86_64/src/libming-ming-0_4_8/src/actioncompiler/swf4compiler.flex"
{ count();	return ORD;	}
	YY_BREAK
case 24:
YY_RULE_SETUP
#line 144 "/usr/src/ports/ming/ming-0.4.8-2.x86_64/src/libming-ming-0_4_8/src/actioncompiler/swf4compiler.flex"
{ count();	return CHR;	}
	YY_BREAK
case 25:
YY_RULE_SETUP
#line 145 "/usr/src/ports/ming/ming-0.4.8-2.x86_64/src/libming-ming-0_4_8/src/actioncompiler/swf4compiler.flex"
{ count();	return CALLFRAME;	}
	YY_BREAK
case 26:
YY_RULE_SETUP
#line 146 "/usr/src/ports/ming/ming-0.4.8-2.x86_64/src/libming-ming-0_4_8/src/actioncompiler/swf4compiler.flex"
{ count();	return GETURL;	}
	YY_BREAK
case 27:
YY_RULE_SETUP
#line 147 "/usr/src/ports/ming/ming-0.4.8-2.x86_64/src/libming-ming-0_4_8/src/actioncompiler/swf4compiler.flex"
{ count();	return GETURL1;	}
	YY_BREAK
case 28:
YY_RULE_SETUP
#line 148 "/usr/src/ports/ming/ming-0.4.8-2.x86_64/src/libming-ming-0_4_8/src/actioncompiler/swf4compiler.flex"
{ count();	return LOADMOVIE;	}
	YY_BREAK
case 29:
YY_RULE_SETUP
#line 149 "/usr/src/ports/ming/ming-0.4.8-2.x86_64/src/libming-ming-0_4_8/src/actioncompiler/swf4compiler.flex"
{ count();	return LOADMOVIENUM;	}
	YY_BREAK
case 30:
YY_RULE_SETUP
#line 150 "/usr/src/ports/ming/ming-0.4.8-2.x86_64/src/libming-ming-0_4_8/src/actioncompiler/swf4compiler.flex"
{ count();	return LOADVARIABLES;	}
	YY_BREAK
case 31:
YY_RULE_SETUP
#line 151 "/usr/src/ports/ming/ming-0.4.8-2.x86_64/src/libming-ming-0_4_8/src/actioncompiler/swf4compiler.flex"
{ count();	return SUBSTR;	}
	YY_BREAK
case 32:
YY_RULE_SETUP
#line 153 "/usr/src/ports/ming/ming-0.4.8-2.x86_64/src/libming-ming-0_4_8/src/actioncompiler/swf4compiler.flex"
{ count();	return GETPROPERTY;	}
	YY_BREAK
/* v3 functions */
case 33:
YY_RULE_SETUP
#line 156 "/usr/src/ports/ming/ming-0.4.8-2.x86_64/src/libming-ming-0_4_8/src/actioncompiler/swf4compiler.flex"
{ count();	return NEXTFRAME;	}
	YY_BREAK
case 34:
YY_RULE_SETUP
#line 157 "/usr/src/ports/ming/ming-0.4.8-2.x86_64/src/libming-ming-0_4_8/src/actioncompiler/swf4compiler.flex"
{ count();	return PREVFRAME;	}
	YY_BREAK
case 35:
YY_RULE_SETUP
#line 158 "/usr/src/ports/ming/ming-0.4.8-2.x86_64/src/libming-ming-0_4_8/src/actioncompiler/swf4compiler.flex"
{ count();	return PLAY;		}
	YY_BREAK
case 36:
YY_RULE_SETUP
#line 159 "/usr/src/ports/ming/ming-0.4.8-2.x86_64/src/libming-ming-0_4_8/src/actioncompiler/swf4compiler.flex"
{ count();	return STOP;		}
	YY_BREAK
case 37:
YY_RULE_SETUP
#line 160 "/usr/src/ports/ming/ming-0.4.8-2.x86_64/src/libming-ming-0_4_8/src/actioncompiler/swf4compiler.flex"
{ count();	return TOGGLEQUALITY;	}
	YY_BREAK
case 38:
YY_RULE_SETUP
#line 161 "/usr/src/ports/ming/ming-0.4.8-2.x86_64/src/libming-ming-0_4_8/src/actioncompiler/swf4compiler.flex"
{ count();	return STOPSOUNDS;	}
	YY_BREAK
case 39:
YY_RULE_SETUP
#line 162 "/usr/src/ports/ming/ming-0.4.8-2.x86_64/src/libming-ming-0_4_8/src/actioncompiler/swf4compiler.flex"
{ count();	return GOTOFRAME;	}
	YY_BREAK
case 40:
YY_RULE_SETUP
#line 163 "/usr/src/ports/ming/ming-0.4.8-2.x86_64/src/libming-ming-0_4_8/src/actioncompiler/swf4compiler.flex"
{ count();	return GOTOANDPLAY;	}
	YY_BREAK
case 41:
YY_RULE_SETUP
#line 164 "/usr/src/ports/ming/ming-0.4.8-2.x86_64/src/libming-ming-0_4_8/src/actioncompiler/swf4compiler.flex"
{ count();	return FRAMELOADED;	}
	YY_BREAK
case 42:
YY_RULE_SETUP
#line 165 "/usr/src/ports/ming/ming-0.4.8-2.x86_64/src/libming-ming-0_4_8/src/actioncompiler/swf4compiler.flex"
{ count();	return SETTARGET;	}
	YY_BREAK
/* high level functions */
case 43:
YY_RULE_SETUP
#line 168 "/usr/src/ports/ming/ming-0.4.8-2.x86_64/src/libming-ming-0_4_8/src/actioncompiler/swf4compiler.flex"
{ count();	return TELLTARGET;	}
	YY_BREAK
case 44:
YY_RULE_SETUP
#line 171 "/usr/src/ports/ming/ming-0.4.8-2.x86_64/src/libming-ming-0_4_8/src/actioncompiler/swf4compiler.flex"
{ count();      return THIS;	}
	YY_BREAK
case 45:
YY_RULE_SETUP
#line 173 "/usr/src/ports/ming/ming-0.4.8-2.x86_64/src/libming-ming-0_4_8/src/actioncompiler/swf4compiler.flex"
{ count();	BEGIN(asm); return ASM;		}
	YY_BREAK
/* assembler v4 ops */

case 46:
YY_RULE_SETUP
#line 177 "/usr/src/ports/ming/ming-0.4.8-2.x86_64/src/libming-ming-0_4_8/src/actioncompiler/swf4compiler.flex"
{ count();	return ASMADD; }
	YY_BREAK
case 47:
YY_RULE_SETUP
#line 178 "/usr/src/ports/ming/ming-0.4.8-2.x86_64/src/libming-ming-0_4_8/src/actioncompiler/swf4compiler.flex"
{ count();	return ASMSUBSTRACT; }
	YY_BREAK
case 48:
YY_RULE_SETUP
#line 179 "/usr/src/ports/ming/ming-0.4.8-2.x86_64/src/libming-ming-0_4_8/src/actioncompiler/swf4compiler.flex"
{ count();	return ASMDIVIDE; }
	YY_BREAK
case 49:
YY_RULE_SETUP
#line 180 "/usr/src/ports/ming/ming-0.4.8-2.x86_64/src/libming-ming-0_4_8/src/actioncompiler/swf4compiler.flex"
{ count();	return ASMMULTIPLY; }
	YY_BREAK
case 50:
YY_RULE_SETUP
#line 181 "/usr/src/ports/ming/ming-0.4.8-2.x86_64/src/libming-ming-0_4_8/src/actioncompiler/swf4compiler.flex"
{ count();	return ASMEQUALS; }
	YY_BREAK
case 51:
YY_RULE_SETUP
#line 182 "/usr/src/ports/ming/ming-0.4.8-2.x86_64/src/libming-ming-0_4_8/src/actioncompiler/swf4compiler.flex"
{ count();	return ASMLESS; }
	YY_BREAK
case 52:
YY_RULE_SETUP
#line 183 "/usr/src/ports/ming/ming-0.4.8-2.x86_64/src/libming-ming-0_4_8/src/actioncompiler/swf4compiler.flex"
{ count();	return ASMLOGICALAND; }
	YY_BREAK
case 53:
YY_RULE_SETUP
#line 184 "/usr/src/ports/ming/ming-0.4.8-2.x86_64/src/libming-ming-0_4_8/src/actioncompiler/swf4compiler.flex"
{ count();	return ASMLOGICALOR; }
	YY_BREAK
case 54:
YY_RULE_SETUP
#line 185 "/usr/src/ports/ming/ming-0.4.8-2.x86_64/src/libming-ming-0_4_8/src/actioncompiler/swf4compiler.flex"
{ count();	return ASMLOGICALNOT; }
	YY_BREAK
case 55:
YY_RULE_SETUP
#line 186 "/usr/src/ports/ming/ming-0.4.8-2.x86_64/src/libming-ming-0_4_8/src/actioncompiler/swf4compiler.flex"
{ count();	return ASMSTRINGAND; }
	YY_BREAK
case 56:
YY_RULE_SETUP
#line 187 "/usr/src/ports/ming/ming-0.4.8-2.x86_64/src/libming-ming-0_4_8/src/actioncompiler/swf4compiler.flex"
{ count();	return ASMSTRINGEQUALS; }
	YY_BREAK
case 57:
YY_RULE_SETUP
#line 188 "/usr/src/ports/ming/ming-0.4.8-2.x86_64/src/libming-ming-0_4_8/src/actioncompiler/swf4compiler.flex"
{ count();	return ASMSTRINGEXTRACT; }
	YY_BREAK
case 58:
YY_RULE_SETUP
#line 189 "/usr/src/ports/ming/ming-0.4.8-2.x86_64/src/libming-ming-0_4_8/src/actioncompiler/swf4compiler.flex"
{ count();	return ASMSTRINGLENGTH; }
	YY_BREAK
case 59:
YY_RULE_SETUP
#line 190 "/usr/src/ports/ming/ming-0.4.8-2.x86_64/src/libming-ming-0_4_8/src/actioncompiler/swf4compiler.flex"
{ count();	return ASMMBSTRINGEXTRACT; }
	YY_BREAK
case 60:
YY_RULE_SETUP
#line 191 "/usr/src/ports/ming/ming-0.4.8-2.x86_64/src/libming-ming-0_4_8/src/actioncompiler/swf4compiler.flex"
{ count();	return ASMMBSTRINGLENGTH; }
	YY_BREAK
case 61:
YY_RULE_SETUP
#line 192 "/usr/src/ports/ming/ming-0.4.8-2.x86_64/src/libming-ming-0_4_8/src/actioncompiler/swf4compiler.flex"
{ count();	return ASMSTRINGLESS; }
	YY_BREAK
case 62:
YY_RULE_SETUP
#line 193 "/usr/src/ports/ming/ming-0.4.8-2.x86_64/src/libming-ming-0_4_8/src/actioncompiler/swf4compiler.flex"
{ count();	return ASMPOP; }
	YY_BREAK
case 63:
YY_RULE_SETUP
#line 194 "/usr/src/ports/ming/ming-0.4.8-2.x86_64/src/libming-ming-0_4_8/src/actioncompiler/swf4compiler.flex"
{ count();	return ASMPUSH; }
	YY_BREAK
case 64:
YY_RULE_SETUP
#line 195 "/usr/src/ports/ming/ming-0.4.8-2.x86_64/src/libming-ming-0_4_8/src/actioncompiler/swf4compiler.flex"
{ count();	return ASMASCIITOCHAR; }
	YY_BREAK
case 65:
YY_RULE_SETUP
#line 196 "/usr/src/ports/ming/ming-0.4.8-2.x86_64/src/libming-ming-0_4_8/src/actioncompiler/swf4compiler.flex"
{ count();	return ASMCHARTOASCII; }
	YY_BREAK
case 66:
YY_RULE_SETUP
#line 197 "/usr/src/ports/ming/ming-0.4.8-2.x86_64/src/libming-ming-0_4_8/src/actioncompiler/swf4compiler.flex"
{ count();	return ASMTOINTEGER; }
	YY_BREAK
case 67:
YY_RULE_SETUP
#line 198 "/usr/src/ports/ming/ming-0.4.8-2.x86_64/src/libming-ming-0_4_8/src/actioncompiler/swf4compiler.flex"
{ count();	return ASMMBASCIITOCHAR; }
	YY_BREAK
case 68:
YY_RULE_SETUP
#line 199 "/usr/src/ports/ming/ming-0.4.8-2.x86_64/src/libming-ming-0_4_8/src/actioncompiler/swf4compiler.flex"
{ count();	return ASMMBCHARTOASCII; }
	YY_BREAK
case 69:
YY_RULE_SETUP
#line 200 "/usr/src/ports/ming/ming-0.4.8-2.x86_64/src/libming-ming-0_4_8/src/actioncompiler/swf4compiler.flex"
{ count();	return ASMCALL;	}
	YY_BREAK
case 70:
YY_RULE_SETUP
#line 201 "/usr/src/ports/ming/ming-0.4.8-2.x86_64/src/libming-ming-0_4_8/src/actioncompiler/swf4compiler.flex"
{ count();	return ASMIF; }
	YY_BREAK
case 71:
YY_RULE_SETUP
#line 202 "/usr/src/ports/ming/ming-0.4.8-2.x86_64/src/libming-ming-0_4_8/src/actioncompiler/swf4compiler.flex"
{ count();	return ASMJUMP; }
	YY_BREAK
case 72:
YY_RULE_SETUP
#line 203 "/usr/src/ports/ming/ming-0.4.8-2.x86_64/src/libming-ming-0_4_8/src/actioncompiler/swf4compiler.flex"
{ count();	return ASMGETVARIABLE; }
	YY_BREAK
case 73:
YY_RULE_SETUP
#line 204 "/usr/src/ports/ming/ming-0.4.8-2.x86_64/src/libming-ming-0_4_8/src/actioncompiler/swf4compiler.flex"
{ count();	return ASMSETVARIABLE; }
	YY_BREAK
case 74:
YY_RULE_SETUP
#line 205 "/usr/src/ports/ming/ming-0.4.8-2.x86_64/src/libming-ming-0_4_8/src/actioncompiler/swf4compiler.flex"
{ count();	return ASMGETURL2; }
	YY_BREAK
case 75:
YY_RULE_SETUP
#line 206 "/usr/src/ports/ming/ming-0.4.8-2.x86_64/src/libming-ming-0_4_8/src/actioncompiler/swf4compiler.flex"
{ count();	return ASMGETPROPERTY; }
	YY_BREAK
case 76:
YY_RULE_SETUP
#line 207 "/usr/src/ports/ming/ming-0.4.8-2.x86_64/src/libming-ming-0_4_8/src/actioncompiler/swf4compiler.flex"
{ count();	return ASMGOTOFRAME2; }
	YY_BREAK
case 77:
YY_RULE_SETUP
#line 208 "/usr/src/ports/ming/ming-0.4.8-2.x86_64/src/libming-ming-0_4_8/src/actioncompiler/swf4compiler.flex"
{ count();	return ASMREMOVESPRITE; }
	YY_BREAK
case 78:
YY_RULE_SETUP
#line 209 "/usr/src/ports/ming/ming-0.4.8-2.x86_64/src/libming-ming-0_4_8/src/actioncompiler/swf4compiler.flex"
{ count();	return ASMSETPROPERTY; }
	YY_BREAK
case 79:
YY_RULE_SETUP
#line 210 "/usr/src/ports/ming/ming-0.4.8-2.x86_64/src/libming-ming-0_4_8/src/actioncompiler/swf4compiler.flex"
{ count();	return ASMSETTARGET2; }
	YY_BREAK
case 80:
YY_RULE_SETUP
#line 211 "/usr/src/ports/ming/ming-0.4.8-2.x86_64/src/libming-ming-0_4_8/src/actioncompiler/swf4compiler.flex"
{ count();	return ASMSTARTDRAG; }
	YY_BREAK
case 81:
YY_RULE_SETUP
#line 212 "/usr/src/ports/ming/ming-0.4.8-2.x86_64/src/libming-ming-0_4_8/src/actioncompiler/swf4compiler.flex"
{ count();	return ASMWAITFORFRAME2; }
	YY_BREAK
case 82:
YY_RULE_SETUP
#line 213 "/usr/src/ports/ming/ming-0.4.8-2.x86_64/src/libming-ming-0_4_8/src/actioncompiler/swf4compiler.flex"
{ count();	return ASMCLONESPRITE; }
	YY_BREAK
case 83:
YY_RULE_SETUP
#line 214 "/usr/src/ports/ming/ming-0.4.8-2.x86_64/src/libming-ming-0_4_8/src/actioncompiler/swf4compiler.flex"
{ count();	return ASMENDDRAG; }
	YY_BREAK
case 84:
YY_RULE_SETUP
#line 215 "/usr/src/ports/ming/ming-0.4.8-2.x86_64/src/libming-ming-0_4_8/src/actioncompiler/swf4compiler.flex"
{ count();	return ASMGETTIME; }
	YY_BREAK
case 85:
YY_RULE_SETUP
#line 216 "/usr/src/ports/ming/ming-0.4.8-2.x86_64/src/libming-ming-0_4_8/src/actioncompiler/swf4compiler.flex"
{ count();	return ASMRANDOMNUMBER; }
	YY_BREAK
case 86:
YY_RULE_SETUP
#line 217 "/usr/src/ports/ming/ming-0.4.8-2.x86_64/src/libming-ming-0_4_8/src/actioncompiler/swf4compiler.flex"
{ count();	return ASMTRACE; }
	YY_BREAK

case 87:
YY_RULE_SETUP
#line 220 "/usr/src/ports/ming/ming-0.4.8-2.x86_64/src/libming-ming-0_4_8/src/actioncompiler/swf4compiler.flex"
{ count();	swf4lval.str = strdup(yytext);
					return IDENTIFIER;	}
	YY_BREAK
case 88:
YY_RULE_SETUP
#line 223 "/usr/src/ports/ming/ming-0.4.8-2.x86_64/src/libming-ming-0_4_8/src/actioncompiler/swf4compiler.flex"
{ count();	swf4lval.str = strdup(yytext);
					return PATH;    }
	YY_BREAK
case 89:
YY_RULE_SETUP
#line 226 "/usr/src/ports/ming/ming-0.4.8-2.x86_64/src/libming-ming-0_4_8/src/actioncompiler/swf4compiler.flex"
{ count();	swf4lval.str = strdup(yytext);
					return PATH;    }
	YY_BREAK
case 90:
/* rule 90 can match eol */
YY_RULE_SETUP
#line 229 "/usr/src/ports/ming/ming-0.4.8-2.x86_64/src/libming-ming-0_4_8/src/actioncompiler/swf4compiler.flex"
{ count();	swf4lval.str = strdup(yytext+1);
					swf4lval.str[strlen(swf4lval.str)-1]=0;
                                        unescape(swf4lval.str);
					return STRING;		}
	YY_BREAK
case 91:
/* rule 91 can match eol */
YY_RULE_SETUP
#line 234 "/usr/src/ports/ming/ming-0.4.8-2.x86_64/src/libming-ming-0_4_8/src/actioncompiler/swf4compiler.flex"
{ count();	swf4lval.str = strdup(yytext+1);
					swf4lval.str[strlen(swf4lval.str)-1]=0;
                                        unescape(swf4lval.str);
					return STRING; 		}
	YY_BREAK
case 92:
/* rule 92 can match eol */
*yy_cp = (yy_hold_char); /* undo effects of setting up yytext */
YY_LINENO_REWIND_TO(yy_cp - 1);
(yy_c_buf_p) = yy_cp -= 1;
YY_DO_BEFORE_ACTION; /* set up yytext again */
YY_RULE_SETUP
#line 239 "/usr/src/ports/ming/ming-0.4.8-2.x86_64/src/libming-ming-0_4_8/src/actioncompiler/swf4compiler.flex"
{ count();	swf4lval.str = NULL;
					warning("Unterminated string!");
					return BROKENSTRING;		}
	YY_BREAK
case 93:
/* rule 93 can match eol */
*yy_cp = (yy_hold_char); /* undo effects of setting up yytext */
YY_LINENO_REWIND_TO(yy_cp - 1);
(yy_c_buf_p) = yy_cp -= 1;
YY_DO_BEFORE_ACTION; /* set up yytext again */
YY_RULE_SETUP
#line 243 "/usr/src/ports/ming/ming-0.4.8-2.x86_64/src/libming-ming-0_4_8/src/actioncompiler/swf4compiler.flex"
{ count();	swf4lval.str = NULL;
					warning("Unterminated string!");
					return BROKENSTRING;		}
	YY_BREAK
case 94:
YY_RULE_SETUP
#line 247 "/usr/src/ports/ming/ming-0.4.8-2.x86_64/src/libming-ming-0_4_8/src/actioncompiler/swf4compiler.flex"
{ count();	comment();		}
	YY_BREAK
case 95:
YY_RULE_SETUP
#line 248 "/usr/src/ports/ming/ming-0.4.8-2.x86_64/src/libming-ming-0_4_8/src/actioncompiler/swf4compiler.flex"
{ count();	comment1();		}
	YY_BREAK
case 96:
YY_RULE_SETUP
#line 249 "/usr/src/ports/ming/ming-0.4.8-2.x86_64/src/libming-ming-0_4_8/src/actioncompiler/swf4compiler.flex"
{ count(); }
	YY_BREAK
case 97:
YY_RULE_SETUP
#line 251 "/usr/src/ports/ming/ming-0.4.8-2.x86_64/src/libming-ming-0_4_8/src/actioncompiler/swf4compiler.flex"
{ count();	return INC; }
	YY_BREAK
case 98:
YY_RULE_SETUP
#line 252 "/usr/src/ports/ming/ming-0.4.8-2.x86_64/src/libming-ming-0_4_8/src/actioncompiler/swf4compiler.flex"
{ count();	return DEC; }
	YY_BREAK
case 99:
YY_RULE_SETUP
#line 253 "/usr/src/ports/ming/ming-0.4.8-2.x86_64/src/libming-ming-0_4_8/src/actioncompiler/swf4compiler.flex"
{ count();	return '<'; }
	YY_BREAK
case 100:
YY_RULE_SETUP
#line 254 "/usr/src/ports/ming/ming-0.4.8-2.x86_64/src/libming-ming-0_4_8/src/actioncompiler/swf4compiler.flex"
{ count();	return '>'; }
	YY_BREAK
case 101:
YY_RULE_SETUP
#line 255 "/usr/src/ports/ming/ming-0.4.8-2.x86_64/src/libming-ming-0_4_8/src/actioncompiler/swf4compiler.flex"
{ count();	return LE; }
	YY_BREAK
case 102:
YY_RULE_SETUP
#line 256 "/usr/src/ports/ming/ming-0.4.8-2.x86_64/src/libming-ming-0_4_8/src/actioncompiler/swf4compiler.flex"
{ count();	return GE; }
	YY_BREAK
case 103:
YY_RULE_SETUP
#line 257 "/usr/src/ports/ming/ming-0.4.8-2.x86_64/src/libming-ming-0_4_8/src/actioncompiler/swf4compiler.flex"
{ count();	return EQ; }
	YY_BREAK
case 104:
YY_RULE_SETUP
#line 258 "/usr/src/ports/ming/ming-0.4.8-2.x86_64/src/libming-ming-0_4_8/src/actioncompiler/swf4compiler.flex"
{ count();	return NE; }
	YY_BREAK
case 105:
YY_RULE_SETUP
#line 259 "/usr/src/ports/ming/ming-0.4.8-2.x86_64/src/libming-ming-0_4_8/src/actioncompiler/swf4compiler.flex"
{ count();	return LAN; }
	YY_BREAK
case 106:
YY_RULE_SETUP
#line 260 "/usr/src/ports/ming/ming-0.4.8-2.x86_64/src/libming-ming-0_4_8/src/actioncompiler/swf4compiler.flex"
{ count();	return LOR; }
	YY_BREAK
case 107:
YY_RULE_SETUP
#line 261 "/usr/src/ports/ming/ming-0.4.8-2.x86_64/src/libming-ming-0_4_8/src/actioncompiler/swf4compiler.flex"
{ count();	return MEQ; }
	YY_BREAK
case 108:
YY_RULE_SETUP
#line 262 "/usr/src/ports/ming/ming-0.4.8-2.x86_64/src/libming-ming-0_4_8/src/actioncompiler/swf4compiler.flex"
{ count();	return DEQ; }
	YY_BREAK
case 109:
YY_RULE_SETUP
#line 263 "/usr/src/ports/ming/ming-0.4.8-2.x86_64/src/libming-ming-0_4_8/src/actioncompiler/swf4compiler.flex"
{ count();	return IEQ; }
	YY_BREAK
case 110:
YY_RULE_SETUP
#line 264 "/usr/src/ports/ming/ming-0.4.8-2.x86_64/src/libming-ming-0_4_8/src/actioncompiler/swf4compiler.flex"
{ count();	return SEQ; }
	YY_BREAK
case 111:
YY_RULE_SETUP
#line 265 "/usr/src/ports/ming/ming-0.4.8-2.x86_64/src/libming-ming-0_4_8/src/actioncompiler/swf4compiler.flex"
{ count();	return STREQ; }
	YY_BREAK
case 112:
YY_RULE_SETUP
#line 266 "/usr/src/ports/ming/ming-0.4.8-2.x86_64/src/libming-ming-0_4_8/src/actioncompiler/swf4compiler.flex"
{ count();	return STRNE; }
	YY_BREAK
case 113:
YY_RULE_SETUP
#line 267 "/usr/src/ports/ming/ming-0.4.8-2.x86_64/src/libming-ming-0_4_8/src/actioncompiler/swf4compiler.flex"
{ count();	return STRCMP; }
	YY_BREAK
case 114:
YY_RULE_SETUP
#line 268 "/usr/src/ports/ming/ming-0.4.8-2.x86_64/src/libming-ming-0_4_8/src/actioncompiler/swf4compiler.flex"
{ count();	return PARENT; }
	YY_BREAK
case 115:
YY_RULE_SETUP
#line 270 "/usr/src/ports/ming/ming-0.4.8-2.x86_64/src/libming-ming-0_4_8/src/actioncompiler/swf4compiler.flex"
{ count();	return ';'; }
	YY_BREAK
case 116:
YY_RULE_SETUP
#line 271 "/usr/src/ports/ming/ming-0.4.8-2.x86_64/src/libming-ming-0_4_8/src/actioncompiler/swf4compiler.flex"
{ count();	return '='; }
	YY_BREAK
case 117:
YY_RULE_SETUP
#line 272 "/usr/src/ports/ming/ming-0.4.8-2.x86_64/src/libming-ming-0_4_8/src/actioncompiler/swf4compiler.flex"
{ count();	return '+'; }
	YY_BREAK
case 118:
YY_RULE_SETUP
#line 273 "/usr/src/ports/ming/ming-0.4.8-2.x86_64/src/libming-ming-0_4_8/src/actioncompiler/swf4compiler.flex"
{ count();	return '-'; }
	YY_BREAK
case 119:
YY_RULE_SETUP
#line 274 "/usr/src/ports/ming/ming-0.4.8-2.x86_64/src/libming-ming-0_4_8/src/actioncompiler/swf4compiler.flex"
{ count();	return '&'; }
	YY_BREAK
case 120:
YY_RULE_SETUP
#line 275 "/usr/src/ports/ming/ming-0.4.8-2.x86_64/src/libming-ming-0_4_8/src/actioncompiler/swf4compiler.flex"
{ count();	return '*'; }
	YY_BREAK
case 121:
YY_RULE_SETUP
#line 276 "/usr/src/ports/ming/ming-0.4.8-2.x86_64/src/libming-ming-0_4_8/src/actioncompiler/swf4compiler.flex"
{ count();	return '/'; }
	YY_BREAK
case 122:
YY_RULE_SETUP
#line 277 "/usr/src/ports/ming/ming-0.4.8-2.x86_64/src/libming-ming-0_4_8/src/actioncompiler/swf4compiler.flex"
{ count();	return '!'; }
	YY_BREAK
case 123:
YY_RULE_SETUP
#line 278 "/usr/src/ports/ming/ming-0.4.8-2.x86_64/src/libming-ming-0_4_8/src/actioncompiler/swf4compiler.flex"
{ count();	return '('; }
	YY_BREAK
case 124:
YY_RULE_SETUP
#line 279 "/usr/src/ports/ming/ming-0.4.8-2.x86_64/src/libming-ming-0_4_8/src/actioncompiler/swf4compiler.flex"
{ count();	return ')'; }
	YY_BREAK
case 125:
YY_RULE_SETUP
#line 280 "/usr/src/ports/ming/ming-0.4.8-2.x86_64/src/libming-ming-0_4_8/src/actioncompiler/swf4compiler.flex"
{ count();	return '['; }
	YY_BREAK
case 126:
YY_RULE_SETUP
#line 281 "/usr/src/ports/ming/ming-0.4.8-2.x86_64/src/libming-ming-0_4_8/src/actioncompiler/swf4compiler.flex"
{ count();	return ']'; }
	YY_BREAK
case 127:
YY_RULE_SETUP
#line 282 "/usr/src/ports/ming/ming-0.4.8-2.x86_64/src/libming-ming-0_4_8/src/actioncompiler/swf4compiler.flex"
{ count();	return '{'; }
	YY_BREAK
case 128:
YY_RULE_SETUP
#line 283 "/usr/src/ports/ming/ming-0.4.8-2.x86_64/src/libming-ming-0_4_8/src/actioncompiler/swf4compiler.flex"
{ count();	return '}'; }
	YY_BREAK
case 129:
YY_RULE_SETUP
#line 284 "/usr/src/ports/ming/ming-0.4.8-2.x86_64/src/libming-ming-0_4_8/src/actioncompiler/swf4compiler.flex"
{ count();	return ','; }
	YY_BREAK
case 130:
YY_RULE_SETUP
#line 285 "/usr/src/ports/ming/ming-0.4.8-2.x86_64/src/libming-ming-0_4_8/src/actioncompiler/swf4compiler.flex"
{ count();	return '.'; }
	YY_BREAK
case 131:
YY_RULE_SETUP
#line 286 "/usr/src/ports/ming/ming-0.4.8-2.x86_64/src/libming-ming-0_4_8/src/actioncompiler/swf4compiler.flex"
{ count();	return '?'; }
	YY_BREAK
case 132:
YY_RULE_SETUP
#line 287 "/usr/src/ports/ming/ming-0.4.8-2.x86_64/src/libming-ming-0_4_8/src/actioncompiler/swf4compiler.flex"
{ count();	return ':'; }
	YY_BREAK
case 133:
/* rule 133 can match eol */
YY_RULE_SETUP
#line 289 "/usr/src/ports/ming/ming-0.4.8-2.x86_64/src/libming-ming-0_4_8/src/actioncompiler/swf4compiler.flex"
{ count();	column = 0;
					strcpy(szLine, yytext + 1);
					++sLineNumber;	yyless(1);	}
	YY_BREAK
case 134:
YY_RULE_SETUP
#line 293 "/usr/src/ports/ming/ming-0.4.8-2.x86_64/src/libming-ming-0_4_8/src/actioncompiler/swf4compiler.flex"
printf( "Unrecognized character: %s\n", yytext );
	YY_BREAK
case 135:
YY_RULE_SETUP
#line 295 "/usr/src/ports/ming/ming-0.4.8-2.x86_64/src/libming-ming-0_4_8/src/actioncompiler/swf4compiler.flex"
ECHO;
	YY_BREAK
#line 2290 "lex.swf4.c"
case YY_STATE_EOF(INITIAL):
case YY_STATE_EOF(asm):
	yyterminate();

	case YY_END_OF_BUFFER:
		{
		/* Amount of text matched not including the EOB char. */
		int yy_amount_of_matched_text = (int) (yy_cp - (yytext_ptr)) - 1;

		/* Undo the effects of YY_DO_BEFORE_ACTION. */
		*yy_cp = (yy_hold_char);
		YY_RESTORE_YY_MORE_OFFSET

		if ( YY_CURRENT_BUFFER_LVALUE->yy_buffer_status == YY_BUFFER_NEW )
			{
			/* We're scanning a new file or input source.  It's
			 * possible that this happened because the user
			 * just pointed yyin at a new source and called
			 * yylex().  If so, then we have to assure
			 * consistency between YY_CURRENT_BUFFER and our
			 * globals.  Here is the right place to do so, because
			 * this is the first action (other than possibly a
			 * back-up) that will match for the new input source.
			 */
			(yy_n_chars) = YY_CURRENT_BUFFER_LVALUE->yy_n_chars;
			YY_CURRENT_BUFFER_LVALUE->yy_input_file = yyin;
			YY_CURRENT_BUFFER_LVALUE->yy_buffer_status = YY_BUFFER_NORMAL;
			}

		/* Note that here we test for yy_c_buf_p "<=" to the position
		 * of the first EOB in the buffer, since yy_c_buf_p will
		 * already have been incremented past the NUL character
		 * (since all states make transitions on EOB to the
		 * end-of-buffer state).  Contrast this with the test
		 * in input().
		 */
		if ( (yy_c_buf_p) <= &YY_CURRENT_BUFFER_LVALUE->yy_ch_buf[(yy_n_chars)] )
			{ /* This was really a NUL. */
			yy_state_type yy_next_state;

			(yy_c_buf_p) = (yytext_ptr) + yy_amount_of_matched_text;

			yy_current_state = yy_get_previous_state(  );

			/* Okay, we're now positioned to make the NUL
			 * transition.  We couldn't have
			 * yy_get_previous_state() go ahead and do it
			 * for us because it doesn't know how to deal
			 * with the possibility of jamming (and we don't
			 * want to build jamming into it because then it
			 * will run more slowly).
			 */

			yy_next_state = yy_try_NUL_trans( yy_current_state );

			yy_bp = (yytext_ptr) + YY_MORE_ADJ;

			if ( yy_next_state )
				{
				/* Consume the NUL. */
				yy_cp = ++(yy_c_buf_p);
				yy_current_state = yy_next_state;
				goto yy_match;
				}

			else
				{
				yy_cp = (yy_last_accepting_cpos);
				yy_current_state = (yy_last_accepting_state);
				goto yy_find_action;
				}
			}

		else switch ( yy_get_next_buffer(  ) )
			{
			case EOB_ACT_END_OF_FILE:
				{
				(yy_did_buffer_switch_on_eof) = 0;

				if ( yywrap(  ) )
					{
					/* Note: because we've taken care in
					 * yy_get_next_buffer() to have set up
					 * yytext, we can now set up
					 * yy_c_buf_p so that if some total
					 * hoser (like flex itself) wants to
					 * call the scanner after we return the
					 * YY_NULL, it'll still work - another
					 * YY_NULL will get returned.
					 */
					(yy_c_buf_p) = (yytext_ptr) + YY_MORE_ADJ;

					yy_act = YY_STATE_EOF(YY_START);
					goto do_action;
					}

				else
					{
					if ( ! (yy_did_buffer_switch_on_eof) )
						YY_NEW_FILE;
					}
				break;
				}

			case EOB_ACT_CONTINUE_SCAN:
				(yy_c_buf_p) =
					(yytext_ptr) + yy_amount_of_matched_text;

				yy_current_state = yy_get_previous_state(  );

				yy_cp = (yy_c_buf_p);
				yy_bp = (yytext_ptr) + YY_MORE_ADJ;
				goto yy_match;

			case EOB_ACT_LAST_MATCH:
				(yy_c_buf_p) =
				&YY_CURRENT_BUFFER_LVALUE->yy_ch_buf[(yy_n_chars)];

				yy_current_state = yy_get_previous_state(  );

				yy_cp = (yy_c_buf_p);
				yy_bp = (yytext_ptr) + YY_MORE_ADJ;
				goto yy_find_action;
			}
		break;
		}

	default:
		YY_FATAL_ERROR(
			"fatal flex scanner internal error--no action found" );
	} /* end of action switch */
		} /* end of scanning one token */
	} /* end of user's declarations */
} /* end of yylex */

/* yy_get_next_buffer - try to read in a new buffer
 *
 * Returns a code representing an action:
 *	EOB_ACT_LAST_MATCH -
 *	EOB_ACT_CONTINUE_SCAN - continue scanning from current position
 *	EOB_ACT_END_OF_FILE - end of file
 */
static int yy_get_next_buffer (void)
{
    	char *dest = YY_CURRENT_BUFFER_LVALUE->yy_ch_buf;
	char *source = (yytext_ptr);
	int number_to_move, i;
	int ret_val;

	if ( (yy_c_buf_p) > &YY_CURRENT_BUFFER_LVALUE->yy_ch_buf[(yy_n_chars) + 1] )
		YY_FATAL_ERROR(
		"fatal flex scanner internal error--end of buffer missed" );

	if ( YY_CURRENT_BUFFER_LVALUE->yy_fill_buffer == 0 )
		{ /* Don't try to fill the buffer, so this is an EOF. */
		if ( (yy_c_buf_p) - (yytext_ptr) - YY_MORE_ADJ == 1 )
			{
			/* We matched a single character, the EOB, so
			 * treat this as a final EOF.
			 */
			return EOB_ACT_END_OF_FILE;
			}

		else
			{
			/* We matched some text prior to the EOB, first
			 * process it.
			 */
			return EOB_ACT_LAST_MATCH;
			}
		}

	/* Try to read more data. */

	/* First move last chars to start of buffer. */
	number_to_move = (int) ((yy_c_buf_p) - (yytext_ptr) - 1);

	for ( i = 0; i < number_to_move; ++i )
		*(dest++) = *(source++);

	if ( YY_CURRENT_BUFFER_LVALUE->yy_buffer_status == YY_BUFFER_EOF_PENDING )
		/* don't do the read, it's not guaranteed to return an EOF,
		 * just force an EOF
		 */
		YY_CURRENT_BUFFER_LVALUE->yy_n_chars = (yy_n_chars) = 0;

	else
		{
			int num_to_read =
			YY_CURRENT_BUFFER_LVALUE->yy_buf_size - number_to_move - 1;

		while ( num_to_read <= 0 )
			{ /* Not enough room in the buffer - grow it. */

			/* just a shorter name for the current buffer */
			YY_BUFFER_STATE b = YY_CURRENT_BUFFER_LVALUE;

			int yy_c_buf_p_offset =
				(int) ((yy_c_buf_p) - b->yy_ch_buf);

			if ( b->yy_is_our_buffer )
				{
				int new_size = b->yy_buf_size * 2;

				if ( new_size <= 0 )
					b->yy_buf_size += b->yy_buf_size / 8;
				else
					b->yy_buf_size *= 2;

				b->yy_ch_buf = (char *)
					/* Include room in for 2 EOB chars. */
					yyrealloc( (void *) b->yy_ch_buf,
							 (yy_size_t) (b->yy_buf_size + 2)  );
				}
			else
				/* Can't grow it, we don't own it. */
				b->yy_ch_buf = NULL;

			if ( ! b->yy_ch_buf )
				YY_FATAL_ERROR(
				"fatal error - scanner input buffer overflow" );

			(yy_c_buf_p) = &b->yy_ch_buf[yy_c_buf_p_offset];

			num_to_read = YY_CURRENT_BUFFER_LVALUE->yy_buf_size -
						number_to_move - 1;

			}

		if ( num_to_read > YY_READ_BUF_SIZE )
			num_to_read = YY_READ_BUF_SIZE;

		/* Read in more data. */
		YY_INPUT( (&YY_CURRENT_BUFFER_LVALUE->yy_ch_buf[number_to_move]),
			(yy_n_chars), num_to_read );

		YY_CURRENT_BUFFER_LVALUE->yy_n_chars = (yy_n_chars);
		}

	if ( (yy_n_chars) == 0 )
		{
		if ( number_to_move == YY_MORE_ADJ )
			{
			ret_val = EOB_ACT_END_OF_FILE;
			yyrestart( yyin  );
			}

		else
			{
			ret_val = EOB_ACT_LAST_MATCH;
			YY_CURRENT_BUFFER_LVALUE->yy_buffer_status =
				YY_BUFFER_EOF_PENDING;
			}
		}

	else
		ret_val = EOB_ACT_CONTINUE_SCAN;

	if (((yy_n_chars) + number_to_move) > YY_CURRENT_BUFFER_LVALUE->yy_buf_size) {
		/* Extend the array by 50%, plus the number we really need. */
		int new_size = (yy_n_chars) + number_to_move + ((yy_n_chars) >> 1);
		YY_CURRENT_BUFFER_LVALUE->yy_ch_buf = (char *) yyrealloc(
			(void *) YY_CURRENT_BUFFER_LVALUE->yy_ch_buf, (yy_size_t) new_size  );
		if ( ! YY_CURRENT_BUFFER_LVALUE->yy_ch_buf )
			YY_FATAL_ERROR( "out of dynamic memory in yy_get_next_buffer()" );
		/* "- 2" to take care of EOB's */
		YY_CURRENT_BUFFER_LVALUE->yy_buf_size = (int) (new_size - 2);
	}

	(yy_n_chars) += number_to_move;
	YY_CURRENT_BUFFER_LVALUE->yy_ch_buf[(yy_n_chars)] = YY_END_OF_BUFFER_CHAR;
	YY_CURRENT_BUFFER_LVALUE->yy_ch_buf[(yy_n_chars) + 1] = YY_END_OF_BUFFER_CHAR;

	(yytext_ptr) = &YY_CURRENT_BUFFER_LVALUE->yy_ch_buf[0];

	return ret_val;
}

/* yy_get_previous_state - get the state just before the EOB char was reached */

    static yy_state_type yy_get_previous_state (void)
{
	yy_state_type yy_current_state;
	char *yy_cp;
    
	yy_current_state = (yy_start);

	for ( yy_cp = (yytext_ptr) + YY_MORE_ADJ; yy_cp < (yy_c_buf_p); ++yy_cp )
		{
		YY_CHAR yy_c = (*yy_cp ? yy_ec[YY_SC_TO_UI(*yy_cp)] : 1);
		if ( yy_accept[yy_current_state] )
			{
			(yy_last_accepting_state) = yy_current_state;
			(yy_last_accepting_cpos) = yy_cp;
			}
		while ( yy_chk[yy_base[yy_current_state] + yy_c] != yy_current_state )
			{
			yy_current_state = (int) yy_def[yy_current_state];
			if ( yy_current_state >= 611 )
				yy_c = yy_meta[yy_c];
			}
		yy_current_state = yy_nxt[yy_base[yy_current_state] + yy_c];
		}

	return yy_current_state;
}

/* yy_try_NUL_trans - try to make a transition on the NUL character
 *
 * synopsis
 *	next_state = yy_try_NUL_trans( current_state );
 */
    static yy_state_type yy_try_NUL_trans  (yy_state_type yy_current_state )
{
	int yy_is_jam;
    	char *yy_cp = (yy_c_buf_p);

	YY_CHAR yy_c = 1;
	if ( yy_accept[yy_current_state] )
		{
		(yy_last_accepting_state) = yy_current_state;
		(yy_last_accepting_cpos) = yy_cp;
		}
	while ( yy_chk[yy_base[yy_current_state] + yy_c] != yy_current_state )
		{
		yy_current_state = (int) yy_def[yy_current_state];
		if ( yy_current_state >= 611 )
			yy_c = yy_meta[yy_c];
		}
	yy_current_state = yy_nxt[yy_base[yy_current_state] + yy_c];
	yy_is_jam = (yy_current_state == 610);

		return yy_is_jam ? 0 : yy_current_state;
}

#ifndef YY_NO_UNPUT

    static void yyunput (int c, char * yy_bp )
{
	char *yy_cp;
    
    yy_cp = (yy_c_buf_p);

	/* undo effects of setting up yytext */
	*yy_cp = (yy_hold_char);

	if ( yy_cp < YY_CURRENT_BUFFER_LVALUE->yy_ch_buf + 2 )
		{ /* need to shift things up to make room */
		/* +2 for EOB chars. */
		int number_to_move = (yy_n_chars) + 2;
		char *dest = &YY_CURRENT_BUFFER_LVALUE->yy_ch_buf[
					YY_CURRENT_BUFFER_LVALUE->yy_buf_size + 2];
		char *source =
				&YY_CURRENT_BUFFER_LVALUE->yy_ch_buf[number_to_move];

		while ( source > YY_CURRENT_BUFFER_LVALUE->yy_ch_buf )
			*--dest = *--source;

		yy_cp += (int) (dest - source);
		yy_bp += (int) (dest - source);
		YY_CURRENT_BUFFER_LVALUE->yy_n_chars =
			(yy_n_chars) = (int) YY_CURRENT_BUFFER_LVALUE->yy_buf_size;

		if ( yy_cp < YY_CURRENT_BUFFER_LVALUE->yy_ch_buf + 2 )
			YY_FATAL_ERROR( "flex scanner push-back overflow" );
		}

	*--yy_cp = (char) c;

	(yytext_ptr) = yy_bp;
	(yy_hold_char) = *yy_cp;
	(yy_c_buf_p) = yy_cp;
}

#endif

#ifndef YY_NO_INPUT
#ifdef __cplusplus
    static int yyinput (void)
#else
    static int input  (void)
#endif

{
	int c;
    
	*(yy_c_buf_p) = (yy_hold_char);

	if ( *(yy_c_buf_p) == YY_END_OF_BUFFER_CHAR )
		{
		/* yy_c_buf_p now points to the character we want to return.
		 * If this occurs *before* the EOB characters, then it's a
		 * valid NUL; if not, then we've hit the end of the buffer.
		 */
		if ( (yy_c_buf_p) < &YY_CURRENT_BUFFER_LVALUE->yy_ch_buf[(yy_n_chars)] )
			/* This was really a NUL. */
			*(yy_c_buf_p) = '\0';

		else
			{ /* need more input */
			int offset = (int) ((yy_c_buf_p) - (yytext_ptr));
			++(yy_c_buf_p);

			switch ( yy_get_next_buffer(  ) )
				{
				case EOB_ACT_LAST_MATCH:
					/* This happens because yy_g_n_b()
					 * sees that we've accumulated a
					 * token and flags that we need to
					 * try matching the token before
					 * proceeding.  But for input(),
					 * there's no matching to consider.
					 * So convert the EOB_ACT_LAST_MATCH
					 * to EOB_ACT_END_OF_FILE.
					 */

					/* Reset buffer status. */
					yyrestart( yyin );

					/*FALLTHROUGH*/

				case EOB_ACT_END_OF_FILE:
					{
					if ( yywrap(  ) )
						return 0;

					if ( ! (yy_did_buffer_switch_on_eof) )
						YY_NEW_FILE;
#ifdef __cplusplus
					return yyinput();
#else
					return input();
#endif
					}

				case EOB_ACT_CONTINUE_SCAN:
					(yy_c_buf_p) = (yytext_ptr) + offset;
					break;
				}
			}
		}

	c = *(unsigned char *) (yy_c_buf_p);	/* cast for 8-bit char's */
	*(yy_c_buf_p) = '\0';	/* preserve yytext */
	(yy_hold_char) = *++(yy_c_buf_p);

	return c;
}
#endif	/* ifndef YY_NO_INPUT */

/** Immediately switch to a different input stream.
 * @param input_file A readable stream.
 * 
 * @note This function does not reset the start condition to @c INITIAL .
 */
    void yyrestart  (FILE * input_file )
{
    
	if ( ! YY_CURRENT_BUFFER ){
        yyensure_buffer_stack ();
		YY_CURRENT_BUFFER_LVALUE =
            yy_create_buffer( yyin, YY_BUF_SIZE );
	}

	yy_init_buffer( YY_CURRENT_BUFFER, input_file );
	yy_load_buffer_state(  );
}

/** Switch to a different input buffer.
 * @param new_buffer The new input buffer.
 * 
 */
    void yy_switch_to_buffer  (YY_BUFFER_STATE  new_buffer )
{
    
	/* TODO. We should be able to replace this entire function body
	 * with
	 *		yypop_buffer_state();
	 *		yypush_buffer_state(new_buffer);
     */
	yyensure_buffer_stack ();
	if ( YY_CURRENT_BUFFER == new_buffer )
		return;

	if ( YY_CURRENT_BUFFER )
		{
		/* Flush out information for old buffer. */
		*(yy_c_buf_p) = (yy_hold_char);
		YY_CURRENT_BUFFER_LVALUE->yy_buf_pos = (yy_c_buf_p);
		YY_CURRENT_BUFFER_LVALUE->yy_n_chars = (yy_n_chars);
		}

	YY_CURRENT_BUFFER_LVALUE = new_buffer;
	yy_load_buffer_state(  );

	/* We don't actually know whether we did this switch during
	 * EOF (yywrap()) processing, but the only time this flag
	 * is looked at is after yywrap() is called, so it's safe
	 * to go ahead and always set it.
	 */
	(yy_did_buffer_switch_on_eof) = 1;
}

static void yy_load_buffer_state  (void)
{
    	(yy_n_chars) = YY_CURRENT_BUFFER_LVALUE->yy_n_chars;
	(yytext_ptr) = (yy_c_buf_p) = YY_CURRENT_BUFFER_LVALUE->yy_buf_pos;
	yyin = YY_CURRENT_BUFFER_LVALUE->yy_input_file;
	(yy_hold_char) = *(yy_c_buf_p);
}

/** Allocate and initialize an input buffer state.
 * @param file A readable stream.
 * @param size The character buffer size in bytes. When in doubt, use @c YY_BUF_SIZE.
 * 
 * @return the allocated buffer state.
 */
    YY_BUFFER_STATE yy_create_buffer  (FILE * file, int  size )
{
	YY_BUFFER_STATE b;
    
	b = (YY_BUFFER_STATE) yyalloc( sizeof( struct yy_buffer_state )  );
	if ( ! b )
		YY_FATAL_ERROR( "out of dynamic memory in yy_create_buffer()" );

	b->yy_buf_size = size;

	/* yy_ch_buf has to be 2 characters longer than the size given because
	 * we need to put in 2 end-of-buffer characters.
	 */
	b->yy_ch_buf = (char *) yyalloc( (yy_size_t) (b->yy_buf_size + 2)  );
	if ( ! b->yy_ch_buf )
		YY_FATAL_ERROR( "out of dynamic memory in yy_create_buffer()" );

	b->yy_is_our_buffer = 1;

	yy_init_buffer( b, file );

	return b;
}

/** Destroy the buffer.
 * @param b a buffer created with yy_create_buffer()
 * 
 */
    void yy_delete_buffer (YY_BUFFER_STATE  b )
{
    
	if ( ! b )
		return;

	if ( b == YY_CURRENT_BUFFER ) /* Not sure if we should pop here. */
		YY_CURRENT_BUFFER_LVALUE = (YY_BUFFER_STATE) 0;

	if ( b->yy_is_our_buffer )
		yyfree( (void *) b->yy_ch_buf  );

	yyfree( (void *) b  );
}

/* Initializes or reinitializes a buffer.
 * This function is sometimes called more than once on the same buffer,
 * such as during a yyrestart() or at EOF.
 */
    static void yy_init_buffer  (YY_BUFFER_STATE  b, FILE * file )

{
	int oerrno = errno;
    
	yy_flush_buffer( b );

	b->yy_input_file = file;
	b->yy_fill_buffer = 1;

    /* If b is the current buffer, then yy_init_buffer was _probably_
     * called from yyrestart() or through yy_get_next_buffer.
     * In that case, we don't want to reset the lineno or column.
     */
    if (b != YY_CURRENT_BUFFER){
        b->yy_bs_lineno = 1;
        b->yy_bs_column = 0;
    }

        b->yy_is_interactive = 0;
    
	errno = oerrno;
}

/** Discard all buffered characters. On the next scan, YY_INPUT will be called.
 * @param b the buffer state to be flushed, usually @c YY_CURRENT_BUFFER.
 * 
 */
    void yy_flush_buffer (YY_BUFFER_STATE  b )
{
    	if ( ! b )
		return;

	b->yy_n_chars = 0;

	/* We always need two end-of-buffer characters.  The first causes
	 * a transition to the end-of-buffer state.  The second causes
	 * a jam in that state.
	 */
	b->yy_ch_buf[0] = YY_END_OF_BUFFER_CHAR;
	b->yy_ch_buf[1] = YY_END_OF_BUFFER_CHAR;

	b->yy_buf_pos = &b->yy_ch_buf[0];

	b->yy_at_bol = 1;
	b->yy_buffer_status = YY_BUFFER_NEW;

	if ( b == YY_CURRENT_BUFFER )
		yy_load_buffer_state(  );
}

/** Pushes the new state onto the stack. The new state becomes
 *  the current state. This function will allocate the stack
 *  if necessary.
 *  @param new_buffer The new state.
 *  
 */
void yypush_buffer_state (YY_BUFFER_STATE new_buffer )
{
    	if (new_buffer == NULL)
		return;

	yyensure_buffer_stack();

	/* This block is copied from yy_switch_to_buffer. */
	if ( YY_CURRENT_BUFFER )
		{
		/* Flush out information for old buffer. */
		*(yy_c_buf_p) = (yy_hold_char);
		YY_CURRENT_BUFFER_LVALUE->yy_buf_pos = (yy_c_buf_p);
		YY_CURRENT_BUFFER_LVALUE->yy_n_chars = (yy_n_chars);
		}

	/* Only push if top exists. Otherwise, replace top. */
	if (YY_CURRENT_BUFFER)
		(yy_buffer_stack_top)++;
	YY_CURRENT_BUFFER_LVALUE = new_buffer;

	/* copied from yy_switch_to_buffer. */
	yy_load_buffer_state(  );
	(yy_did_buffer_switch_on_eof) = 1;
}

/** Removes and deletes the top of the stack, if present.
 *  The next element becomes the new top.
 *  
 */
void yypop_buffer_state (void)
{
    	if (!YY_CURRENT_BUFFER)
		return;

	yy_delete_buffer(YY_CURRENT_BUFFER );
	YY_CURRENT_BUFFER_LVALUE = NULL;
	if ((yy_buffer_stack_top) > 0)
		--(yy_buffer_stack_top);

	if (YY_CURRENT_BUFFER) {
		yy_load_buffer_state(  );
		(yy_did_buffer_switch_on_eof) = 1;
	}
}

/* Allocates the stack if it does not exist.
 *  Guarantees space for at least one push.
 */
static void yyensure_buffer_stack (void)
{
	yy_size_t num_to_alloc;
    
	if (!(yy_buffer_stack)) {

		/* First allocation is just for 2 elements, since we don't know if this
		 * scanner will even need a stack. We use 2 instead of 1 to avoid an
		 * immediate realloc on the next call.
         */
      num_to_alloc = 1; /* After all that talk, this was set to 1 anyways... */
		(yy_buffer_stack) = (struct yy_buffer_state**)yyalloc
								(num_to_alloc * sizeof(struct yy_buffer_state*)
								);
		if ( ! (yy_buffer_stack) )
			YY_FATAL_ERROR( "out of dynamic memory in yyensure_buffer_stack()" );

		memset((yy_buffer_stack), 0, num_to_alloc * sizeof(struct yy_buffer_state*));

		(yy_buffer_stack_max) = num_to_alloc;
		(yy_buffer_stack_top) = 0;
		return;
	}

	if ((yy_buffer_stack_top) >= ((yy_buffer_stack_max)) - 1){

		/* Increase the buffer to prepare for a possible push. */
		yy_size_t grow_size = 8 /* arbitrary grow size */;

		num_to_alloc = (yy_buffer_stack_max) + grow_size;
		(yy_buffer_stack) = (struct yy_buffer_state**)yyrealloc
								((yy_buffer_stack),
								num_to_alloc * sizeof(struct yy_buffer_state*)
								);
		if ( ! (yy_buffer_stack) )
			YY_FATAL_ERROR( "out of dynamic memory in yyensure_buffer_stack()" );

		/* zero only the new slots.*/
		memset((yy_buffer_stack) + (yy_buffer_stack_max), 0, grow_size * sizeof(struct yy_buffer_state*));
		(yy_buffer_stack_max) = num_to_alloc;
	}
}

/** Setup the input buffer state to scan directly from a user-specified character buffer.
 * @param base the character buffer
 * @param size the size in bytes of the character buffer
 * 
 * @return the newly allocated buffer state object.
 */
YY_BUFFER_STATE yy_scan_buffer  (char * base, yy_size_t  size )
{
	YY_BUFFER_STATE b;
    
	if ( size < 2 ||
	     base[size-2] != YY_END_OF_BUFFER_CHAR ||
	     base[size-1] != YY_END_OF_BUFFER_CHAR )
		/* They forgot to leave room for the EOB's. */
		return NULL;

	b = (YY_BUFFER_STATE) yyalloc( sizeof( struct yy_buffer_state )  );
	if ( ! b )
		YY_FATAL_ERROR( "out of dynamic memory in yy_scan_buffer()" );

	b->yy_buf_size = (int) (size - 2);	/* "- 2" to take care of EOB's */
	b->yy_buf_pos = b->yy_ch_buf = base;
	b->yy_is_our_buffer = 0;
	b->yy_input_file = NULL;
	b->yy_n_chars = b->yy_buf_size;
	b->yy_is_interactive = 0;
	b->yy_at_bol = 1;
	b->yy_fill_buffer = 0;
	b->yy_buffer_status = YY_BUFFER_NEW;

	yy_switch_to_buffer( b  );

	return b;
}

/** Setup the input buffer state to scan a string. The next call to yylex() will
 * scan from a @e copy of @a str.
 * @param yystr a NUL-terminated string to scan
 * 
 * @return the newly allocated buffer state object.
 * @note If you want to scan bytes that may contain NUL values, then use
 *       yy_scan_bytes() instead.
 */
YY_BUFFER_STATE yy_scan_string (const char * yystr )
{
    
	return yy_scan_bytes( yystr, (int) strlen(yystr) );
}

/** Setup the input buffer state to scan the given bytes. The next call to yylex() will
 * scan from a @e copy of @a bytes.
 * @param yybytes the byte buffer to scan
 * @param _yybytes_len the number of bytes in the buffer pointed to by @a bytes.
 * 
 * @return the newly allocated buffer state object.
 */
YY_BUFFER_STATE yy_scan_bytes  (const char * yybytes, int  _yybytes_len )
{
	YY_BUFFER_STATE b;
	char *buf;
	yy_size_t n;
	int i;
    
	/* Get memory for full buffer, including space for trailing EOB's. */
	n = (yy_size_t) (_yybytes_len + 2);
	buf = (char *) yyalloc( n  );
	if ( ! buf )
		YY_FATAL_ERROR( "out of dynamic memory in yy_scan_bytes()" );

	for ( i = 0; i < _yybytes_len; ++i )
		buf[i] = yybytes[i];

	buf[_yybytes_len] = buf[_yybytes_len+1] = YY_END_OF_BUFFER_CHAR;

	b = yy_scan_buffer( buf, n );
	if ( ! b )
		YY_FATAL_ERROR( "bad buffer in yy_scan_bytes()" );

	/* It's okay to grow etc. this buffer, and we should throw it
	 * away when we're done.
	 */
	b->yy_is_our_buffer = 1;

	return b;
}

#ifndef YY_EXIT_FAILURE
#define YY_EXIT_FAILURE 2
#endif

static void yynoreturn yy_fatal_error (const char* msg )
{
			fprintf( stderr, "%s\n", msg );
	exit( YY_EXIT_FAILURE );
}

/* Redefine yyless() so it works in section 3 code. */

#undef yyless
#define yyless(n) \
	do \
		{ \
		/* Undo effects of setting up yytext. */ \
        int yyless_macro_arg = (n); \
        YY_LESS_LINENO(yyless_macro_arg);\
		yytext[yyleng] = (yy_hold_char); \
		(yy_c_buf_p) = yytext + yyless_macro_arg; \
		(yy_hold_char) = *(yy_c_buf_p); \
		*(yy_c_buf_p) = '\0'; \
		yyleng = yyless_macro_arg; \
		} \
	while ( 0 )

/* Accessor  methods (get/set functions) to struct members. */

/** Get the current line number.
 * 
 */
int yyget_lineno  (void)
{
    
    return yylineno;
}

/** Get the input stream.
 * 
 */
FILE *yyget_in  (void)
{
        return yyin;
}

/** Get the output stream.
 * 
 */
FILE *yyget_out  (void)
{
        return yyout;
}

/** Get the length of the current token.
 * 
 */
int yyget_leng  (void)
{
        return yyleng;
}

/** Get the current token.
 * 
 */

char *yyget_text  (void)
{
        return yytext;
}

/** Set the current line number.
 * @param _line_number line number
 * 
 */
void yyset_lineno (int  _line_number )
{
    
    yylineno = _line_number;
}

/** Set the input stream. This does not discard the current
 * input buffer.
 * @param _in_str A readable stream.
 * 
 * @see yy_switch_to_buffer
 */
void yyset_in (FILE *  _in_str )
{
        yyin = _in_str ;
}

void yyset_out (FILE *  _out_str )
{
        yyout = _out_str ;
}

int yyget_debug  (void)
{
        return yy_flex_debug;
}

void yyset_debug (int  _bdebug )
{
        yy_flex_debug = _bdebug ;
}

static int yy_init_globals (void)
{
        /* Initialization is the same as for the non-reentrant scanner.
     * This function is called from yylex_destroy(), so don't allocate here.
     */

    (yy_buffer_stack) = NULL;
    (yy_buffer_stack_top) = 0;
    (yy_buffer_stack_max) = 0;
    (yy_c_buf_p) = NULL;
    (yy_init) = 0;
    (yy_start) = 0;

/* Defined in main.c */
#ifdef YY_STDINIT
    yyin = stdin;
    yyout = stdout;
#else
    yyin = NULL;
    yyout = NULL;
#endif

    /* For future reference: Set errno on error, since we are called by
     * yylex_init()
     */
    return 0;
}

/* yylex_destroy is for both reentrant and non-reentrant scanners. */
int yylex_destroy  (void)
{
    
    /* Pop the buffer stack, destroying each element. */
	while(YY_CURRENT_BUFFER){
		yy_delete_buffer( YY_CURRENT_BUFFER  );
		YY_CURRENT_BUFFER_LVALUE = NULL;
		yypop_buffer_state();
	}

	/* Destroy the stack itself. */
	yyfree((yy_buffer_stack) );
	(yy_buffer_stack) = NULL;

    /* Reset the globals. This is important in a non-reentrant scanner so the next time
     * yylex() is called, initialization will occur. */
    yy_init_globals( );

    return 0;
}

/*
 * Internal utility routines.
 */

#ifndef yytext_ptr
static void yy_flex_strncpy (char* s1, const char * s2, int n )
{
		
	int i;
	for ( i = 0; i < n; ++i )
		s1[i] = s2[i];
}
#endif

#ifdef YY_NEED_STRLEN
static int yy_flex_strlen (const char * s )
{
	int n;
	for ( n = 0; s[n]; ++n )
		;

	return n;
}
#endif

void *yyalloc (yy_size_t  size )
{
			return malloc(size);
}

void *yyrealloc  (void * ptr, yy_size_t  size )
{
		
	/* The cast to (char *) in the following accommodates both
	 * implementations that use char* generic pointers, and those
	 * that use void* generic pointers.  It works with the latter
	 * because both ANSI C and C++ allow castless assignment from
	 * any pointer type to void*, and deal with argument conversions
	 * as though doing an assignment.
	 */
	return realloc(ptr, size);
}

void yyfree (void * ptr )
{
			free( (char *) ptr );	/* see yyrealloc() for (char *) cast */
}

#define YYTABLES_NAME "yytables"

#line 295 "/usr/src/ports/ming/ming-0.4.8-2.x86_64/src/libming-ming-0_4_8/src/actioncompiler/swf4compiler.flex"

static int getinput() {
#ifdef __cplusplus
					return yyinput();
#else
					return input();
#endif
}

int swf4wrap()
{
  return 1;
}

static void countline()
{
  if(sLineNumber != 0)
    msgline[column] = 0;

  ++sLineNumber;
  column = 0;
  msgline = msgbufs[sLineNumber & 1];
}

static int LineNumber(void)
{
   return (sLineNumber + 1);
}

static int ColumnNumber(void)
{
   return column;
}

static char *LineText(void)
{
  msgline[column] = 0;
  return msgline;
}

static void comment(void)
{
   // Handle block comments

   int c, c1;

loop:
   // We have the start of a comment so look skip everything up to the
   // end of the comment character
   while ((c = getinput()) != '*' && c != EOF)
   {
      if(column < 1023)
         msgline[column] = c;

      ++column;

      // keep the line number in synch
      if (c == '\n')
      {
         // start the output (matches the algorithim in the lexx above)
	 countline();
      }

      if (swf4debug) putchar(c);
   }

   // is this the end of comment character
   if ((c1 = getinput()) != '/' && c != EOF)
   {
      // false start as this was no end of comment
      do_unput4(c1);
      goto loop;
   }

   // write out the start of the end of comment
   if (c != EOF)
      if (swf4debug) putchar(c);

   // write out the end of the end of comment
   if (c1 != EOF) 
      if (swf4debug) putchar(c1);
}

static void comment1(void)
{
   // Handle comment of type 1 (ie '//')

   int c;

   // this is a line comment
   while ((c = getinput()) != '\n' && c != EOF)
   {
      if (swf4debug) putchar(c);

      if(column < 1023)
         msgline[column] = c;

      ++column;
   };

   // keep the line number in synch
   if (c == '\n')
   {
      if (swf4debug) putchar(c);

      countline();
   }
}

static void count(void)
{
   int n;

   // Count the characters to maintain the current column position
   if (yytext[0] == '\n')
   {
      if (swf4debug) printf("\n");
   }
   else
   {
      if (swf4debug) printf("%s", yytext);

      for(n=0; n<yyleng; ++n, ++column)
      {
	if(column < 1023)
	  msgline[column] = yytext[n];
      }

      //-- keep writing the stuff to standard output
      //column += yyleng;
   }
}

static void printprog()
{
  if(sLineNumber)
    SWF_warn("\n%s", msgbufs[(sLineNumber-1)&1]);

  if(column < 1023)
    msgline[column] = 0;

  SWF_warn("\n%s", msgline);
}

static void warning(char *msg)
{
   // print a warning message
   printprog();
   SWF_warn("\n%*s", ColumnNumber(), "^");
   SWF_warn("\nLine %4.4d:  Reason: '%s' \n", LineNumber(), msg);
}

void swf4error(char *msg)
{
  // report a error
  if(strlen(yytext))
  {
    SWF_error("\n%s\n%*s\nLine %i:  Reason: '%s'\n",
	      LineText(), ColumnNumber(), "^", LineNumber(), msg);
  }
  else
  {
    SWF_error("\nLine %d: Reason: 'Unexpected EOF found while looking for input.'\n", LineNumber());
  }
}

